@@ -31,6 +31,7 @@ import com.sun.jersey.multipart.file.StreamDataBodyPart;
 import org.apache.atlas.bulkimport.BulkImportResponse;
 import org.apache.atlas.model.SearchFilter;
 import org.apache.atlas.model.audit.AtlasAuditEntry;
+import org.apache.atlas.model.audit.AuditReductionCriteria;
 import org.apache.atlas.model.audit.AuditSearchParameters;
 import org.apache.atlas.model.audit.EntityAuditEventV2;
 import org.apache.atlas.model.discovery.AtlasQuickSearchResult;
@@ -56,6 +57,7 @@ import org.apache.atlas.model.instance.ClassificationAssociateRequest;
 import org.apache.atlas.model.instance.EntityMutationResponse;
 import org.apache.atlas.model.lineage.AtlasLineageInfo;
 import org.apache.atlas.model.lineage.AtlasLineageInfo.LineageDirection;
+import org.apache.atlas.model.lineage.LineageOnDemandConstraints;
 import org.apache.atlas.model.profile.AtlasUserSavedSearch;
 import org.apache.atlas.model.typedef.AtlasBusinessMetadataDef;
 import org.apache.atlas.model.typedef.AtlasClassificationDef;
@@ -82,6 +84,7 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
@@ -133,6 +136,11 @@ public class AtlasClientV2 extends AtlasBaseClient {
     private static final String GLOSSARY_CATEGORY    = GLOSSARY_URI + "/category";
     private static final String GLOSSARY_CATEGORIES  = GLOSSARY_URI + "/categories";
 
+    //Notification APIs
+    private static final String NOTIFICATION_URI         = BASE_URI + "v2/notification";
+
+    //IndexRecovery APIs
+    private static final String INDEX_RECOVERY_URI = BASE_URI + "v2/indexrecovery";
 
     public AtlasClientV2(String[] baseUrl, String[] basicAuthUserNamePassword) {
         super(baseUrl, basicAuthUserNamePassword);
@@ -172,7 +180,7 @@ public class AtlasClientV2 extends AtlasBaseClient {
     }
 
     @VisibleForTesting
-    AtlasClientV2(WebResource service, Configuration configuration) {
+    public AtlasClientV2(WebResource service, Configuration configuration) {
         super(service, configuration);
     }
 
@@ -584,7 +592,7 @@ public class AtlasClientV2 extends AtlasBaseClient {
     public void addLabels(String typeName, Map<String, String> uniqAttributes, Set<String> labels) throws AtlasServiceException {
         MultivaluedMap<String, String> queryParams = attributesToQueryParams(uniqAttributes);
 
-        callAPI(formatPathParameters(API_V2.SET_LABELS_BY_UNIQUE_ATTRIBUTE, typeName), (Class<?>) null, labels, queryParams);
+        callAPI(formatPathParameters(API_V2.ADD_LABELS_BY_UNIQUE_ATTRIBUTE, typeName), (Class<?>) null, labels, queryParams);
     }
 
     public void removeLabels(String entityGuid, Set<String> labels) throws AtlasServiceException {
@@ -604,7 +612,7 @@ public class AtlasClientV2 extends AtlasBaseClient {
     public void setLabels(String typeName, Map<String, String> uniqAttributes, Set<String> labels) throws AtlasServiceException {
         MultivaluedMap<String, String> queryParams = attributesToQueryParams(uniqAttributes);
 
-        callAPI(formatPathParameters(API_V2.ADD_LABELS_BY_UNIQUE_ATTRIBUTE, typeName), (Class<?>) null, labels, queryParams);
+        callAPI(formatPathParameters(API_V2.SET_LABELS_BY_UNIQUE_ATTRIBUTE, typeName), (Class<?>) null, labels, queryParams);
     }
 
 
@@ -627,6 +635,9 @@ public class AtlasClientV2 extends AtlasBaseClient {
         return callAPI(API_V2.GET_LINEAGE_BY_ATTRIBUTES, AtlasLineageInfo.class, queryParams, typeName);
     }
 
+    public AtlasLineageInfo getLineageInfoOnDemand(String guid, Map<String, LineageOnDemandConstraints> lineageConstraintsByGuid) throws AtlasServiceException {
+        return callAPI(API_V2.LINEAGE_INFO_ON_DEMAND, AtlasLineageInfo.class, lineageConstraintsByGuid, guid);
+    }
 
     /* Discovery APIs */
     public AtlasSearchResult dslSearch(String query) throws AtlasServiceException {
@@ -828,6 +839,14 @@ public class AtlasClientV2 extends AtlasBaseClient {
         });
     }
 
+    public void ageoutAtlasAudits(AuditReductionCriteria auditReductionCriteria, boolean useAuditConfig) throws AtlasServiceException {
+        MultivaluedMap<String, String> queryParams = new MultivaluedMapImpl();
+
+        queryParams.add("useAuditConfig", String.valueOf(useAuditConfig));
+
+        callAPI(API_V2.AGEOUT_ATLAS_AUDITS, List.class, auditReductionCriteria, queryParams);
+    }
+
 
     // Glossary APIs
     public List<AtlasGlossary> getAllGlossaries(String sortByAttribute, int limit, int offset) throws AtlasServiceException {
@@ -1020,6 +1039,26 @@ public class AtlasClientV2 extends AtlasBaseClient {
         return callAPI(API_V2.IMPORT_GLOSSARY, BulkImportResponse.class, multipartEntity);
     }
 
+    public void postNotificationToTopic(String topic, List<String> messages) throws AtlasServiceException {
+        callAPI(formatPathParameters(API_V2.POST_NOTIFICATIONS_TO_TOPIC, topic), (Class<?>) null, messages);
+    }
+
+    public Map<String, String> getIndexRecoveryData() throws AtlasServiceException {
+        return callAPI(API_V2.GET_INDEX_RECOVERY_DATA, Map.class, null);
+    }
+
+    public void startIndexRecovery(Instant startTime) throws AtlasServiceException {
+        MultivaluedMap<String, String> queryParams = new MultivaluedMapImpl();
+
+        queryParams.add("startTime", startTime != null ? String.valueOf(startTime) : null);
+
+        callAPI(API_V2.START_INDEX_RECOVERY, (Class<?>) null, queryParams);
+    }
+
+    @VisibleForTesting
+    public API formatPathWithParameter(API api, String... params) {
+        return formatPathParameters(api, params);
+    }
 
     @Override
     protected API formatPathParameters(API api, String... params) {
@@ -1125,19 +1164,19 @@ public class AtlasClientV2 extends AtlasBaseClient {
         return callAPI(api, typeDefClass, null);
     }
 
-    private <T> String getPathForType(Class<T> typeDefClass) {
+    protected  <T> String getPathForType(Class<T> typeDefClass) {
         if (AtlasEnumDef.class.isAssignableFrom(typeDefClass)) {
             return "enumdef";
         } else if (AtlasEntityDef.class.isAssignableFrom(typeDefClass)) {
             return "entitydef";
         } else if (AtlasClassificationDef.class.isAssignableFrom(typeDefClass)) {
             return "classificationdef";
-        } else if (AtlasStructDef.class.isAssignableFrom(typeDefClass)) {
-            return "structdef";
         } else if (AtlasRelationshipDef.class.isAssignableFrom(typeDefClass)) {
             return "relationshipdef";
         } else if (AtlasBusinessMetadataDef.class.isAssignableFrom(typeDefClass)) {
             return "businessmetadatadef";
+        }else if (AtlasStructDef.class.isAssignableFrom(typeDefClass)) {
+            return "structdef";
         }
 
         // Code should never reach this point
@@ -1195,6 +1234,11 @@ public class AtlasClientV2 extends AtlasBaseClient {
         public static final API_V2 GET_BUSINESS_METADATA_TEMPLATE    = new API_V2(ENTITY_API + "businessmetadata/import/template", HttpMethod.GET, Response.Status.OK, MediaType.APPLICATION_JSON, MediaType.APPLICATION_OCTET_STREAM);
         public static final API_V2 IMPORT_BUSINESS_METADATA          = new API_V2(ENTITY_API + "businessmetadata/import", HttpMethod.POST, Response.Status.OK, MediaType.MULTIPART_FORM_DATA, MediaType.APPLICATION_JSON);
 
+        public static final API_V2 POST_NOTIFICATIONS_TO_TOPIC     = new API_V2(NOTIFICATION_URI + "/topic/%s", HttpMethod.POST, Response.Status.NO_CONTENT);
+
+        public static final API_V2 GET_INDEX_RECOVERY_DATA = new API_V2(INDEX_RECOVERY_URI , HttpMethod.GET, Response.Status.OK);
+        public static final API_V2 START_INDEX_RECOVERY    = new API_V2(INDEX_RECOVERY_URI + "/start", HttpMethod.POST, Response.Status.NO_CONTENT);
+
         // labels APIs
         public static final API_V2 ADD_LABELS                        = new API_V2(ENTITY_API + "guid/%s/labels", HttpMethod.PUT, Response.Status.NO_CONTENT);
         public static final API_V2 ADD_LABELS_BY_UNIQUE_ATTRIBUTE    = new API_V2(ENTITY_API + "uniqueAttribute/type/%s/labels", HttpMethod.PUT, Response.Status.NO_CONTENT);
@@ -1206,6 +1250,7 @@ public class AtlasClientV2 extends AtlasBaseClient {
         // Lineage APIs
         public static final API_V2 LINEAGE_INFO                = new API_V2(LINEAGE_URI, HttpMethod.GET, Response.Status.OK);
         public static final API_V2 GET_LINEAGE_BY_ATTRIBUTES   = new API_V2(LINEAGE_URI + "uniqueAttribute/type/", HttpMethod.GET, Response.Status.OK);
+        public static final API_V2 LINEAGE_INFO_ON_DEMAND      = new API_V2(LINEAGE_URI, HttpMethod.POST, Response.Status.OK);
 
         // Discovery APIs
         public static final API_V2 DSL_SEARCH                  = new API_V2(DSL_SEARCH_URI, HttpMethod.GET, Response.Status.OK);
@@ -1233,6 +1278,7 @@ public class AtlasClientV2 extends AtlasBaseClient {
 
         // Admin APIs
         public static final API_V2 GET_ATLAS_AUDITS            = new API_V2(ATLAS_AUDIT_API, HttpMethod.POST, Response.Status.OK);
+        public static final API_V2 AGEOUT_ATLAS_AUDITS         = new API_V2(ATLAS_AUDIT_API + "ageout/", HttpMethod.POST, Response.Status.OK);
 
         // Glossary APIs
         public static final API_V2 GET_ALL_GLOSSARIES              = new API_V2(GLOSSARY_URI, HttpMethod.GET, Response.Status.OK);
