@@ -93,7 +93,6 @@ module.exports = function(grunt) {
                     'backgrid-paginator.min.js': { 'backgrid-paginator': 'backgrid-paginator/js' },
                     'backgrid-sizeable-columns.js': { 'backgrid-sizeable-columns': 'backgrid-sizeable-columns/js' },
                     'Backgrid.ColumnManager.js': { 'backgrid-columnmanager/src': 'backgrid-columnmanager/js' },
-                    'jquery-asBreadcrumbs.min.js': { 'jquery-asBreadcrumbs/dist': 'jquery-asBreadcrumbs/js' },
                     'd3.min.js': { 'd3/dist': 'd3' },
                     'index.js': { 'd3-tip': 'd3/' },
                     'dagre-d3.min.js': { 'dagre-d3/dist': 'dagre-d3' },
@@ -128,7 +127,6 @@ module.exports = function(grunt) {
                     'backgrid-paginator.css': { 'backgrid-paginator': 'backgrid-paginator/css' },
                     'backgrid-sizeable-columns.css': { 'backgrid-sizeable-columns': 'backgrid-sizeable-columns/css' },
                     'Backgrid.ColumnManager.css': { 'backgrid-columnmanager/lib': 'backgrid-columnmanager/css' },
-                    'asBreadcrumbs.min.css': { 'jquery-asBreadcrumbs/dist/css': 'jquery-asBreadcrumbs/css' },
                     'select2.min.css': { 'select2/dist/css': 'select2/css' },
                     'backgrid-select-all.min.css': { 'backgrid-select-all': 'backgrid-select-all' },
                     'font-awesome.min.css': { 'font-awesome/css': 'font-awesome/css' },
@@ -166,7 +164,6 @@ module.exports = function(grunt) {
                         { 'underscore': 'underscore' },
                         { 'bootstrap': 'bootstrap' },
                         { 'backgrid-columnmanager': 'backgrid-columnmanager' },
-                        { 'jquery-asBreadcrumbs': 'jquery-asBreadcrumbs' },
                         { 'd3': 'd3' },
                         { 'd3-tip': 'd3/' },
                         { 'dagre-d3': 'dagre-d3' },
@@ -237,7 +234,7 @@ module.exports = function(grunt) {
                 files: [{
                     expand: true,
                     cwd: distPath + '/js',
-                    src: ['external_lib/**/*.js', 'libs/**/*.js'],
+                    src: ['external_lib/**/*.js', '!external_lib/**/purify.min.js', 'libs/**/*.js'],
                     dest: distPath + '/js'
                 }]
             },
@@ -250,7 +247,7 @@ module.exports = function(grunt) {
                 files: [{
                     expand: true,
                     cwd: distPath + '/js',
-                    src: ['**/*.js', '!libs/**', '!external_lib/**'],
+                    src: ['**/*.js', '!libs/**', '!external_lib/**/purify.min.js', '!external_lib/**'],
                     dest: distPath + '/js'
                 }]
             }
