@@ -127,7 +127,8 @@ define(['require', 'utils/Utils', 'modules/Modal', 'utils/Messages', 'utils/Enum
                                 newVal = numberFormat(newVal);
                             }
                         }
-                        return getHighlightedString(_.escape(newVal));
+                        newVal = (options && options.isEditorValue) ? newVal : _.escape(newVal);
+                        return getHighlightedString(newVal);
                     }
                 } else {
                     return getEmptyString(key);
@@ -154,7 +155,7 @@ define(['require', 'utils/Utils', 'modules/Modal', 'utils/Messages', 'utils/Enum
                             scope.$('td div[data-id="' + id + '"]').html('<a href="#!/detailPage/' + id + '">' + _.escape(id) + '</a>');
                         }
                         if (deleteButton.length) {
-                            scope.$('td div[data-id="' + id + '"]').addClass('block readOnlyLink');
+                            scope.$('td div[data-id="' + id + '"]').addClass('block whitespace-normal readOnlyLink');
                             scope.$('td div[data-id="' + id + '"]').append(deleteButton);
                         }
                     },
@@ -247,7 +248,7 @@ define(['require', 'utils/Utils', 'modules/Modal', 'utils/Messages', 'utils/Enum
                     if (readOnly) {
                         if (!fetch) {
                             tempLink += '<button title="Deleted" class="btn btn-action btn-md deleteBtn"><i class="fa fa-trash"></i></button>';
-                            subLink += '<div class="block readOnlyLink">' + tempLink + '</div>';
+                            subLink += '<div class="block whitespace-normal readOnlyLink">' + tempLink + '</div>';
                         } else {
                             fetch = false;
                             subLink += tempLink;
@@ -290,7 +291,7 @@ define(['require', 'utils/Utils', 'modules/Modal', 'utils/Messages', 'utils/Enum
             if (defEntity && defEntity.typeName) {
                 var defEntityType = defEntity.typeName.toLocaleLowerCase();
                 if (defEntityType === 'date') {
-                    keyValue = keyValue > 0 ? Utils.formatDate({ date: keyValue }) : null;
+                    keyValue = moment(keyValue)._isValid ? Utils.formatDate({ date: keyValue }) : null;
                 } else if (_.isObject(keyValue)) {
                     keyValue = extractObject({ "keyValue": keyValue, "key": key, 'defEntity': defEntity });
                 }
@@ -634,14 +635,14 @@ define(['require', 'utils/Utils', 'modules/Modal', 'utils/Messages', 'utils/Enum
                             url = [(obj.id || obj.attributeName), mapApiOperatorToUI(obj.operator), value];
                         if (obj.operator === "TIME_RANGE") {
                             if (value.indexOf("-") > -1) {
-                                url[2] = value.split('-').map(function(udKey) {
-                                    return Date.parse(udKey.trim()).toString()
+                                url[2] = value.split(' - ').map(function(udKey) {
+                                    return Globals.needToValidateDate ? Date.parse(Utils.convertToValidDate(udKey.trim())).toString() : Date.parse(udKey.trim()).toString();
                                 }).join(",")
                             } else {
                                 url[2] = Enums.queryBuilderDateRangeUIValueToAPI[_.trim(value)] || value;
                             }
                         } else if (value && value.length && type === 'date' && formatedDateToLong) {
-                            url[2] = Date.parse(value);
+                            url[2] = Globals.needToValidateDate ? Date.parse(Utils.convertToValidDate(value)) : Date.parse(value);
                         }
                         if (type) {
                             url.push(type);
