@@ -75,7 +75,8 @@ define(['require',
             templateHelpers: function() {
                 return {
                     entityUpdate: Globals.entityUpdate,
-                    isTasksEnabled: Globals.isTasksEnabled
+                    isTasksEnabled: Globals.isTasksEnabled,
+                    isUiTasksTabEnabled: Globals.isUiTasksTabEnabled
                 };
             },
             /** ui events hash */
@@ -100,7 +101,7 @@ define(['require',
                 };
                 events["click " + this.ui.termClick] = function(e) {
                     if ((e.target.nodeName.toLocaleLowerCase() != "i") && (!$(e.target).hasClass("parent-list-btn")) && (!$(e.target).hasClass("fa"))) {
-                        var guid = $(e.currentTarget).find('.fa-close').data('guid'),
+                        var guid = $(e.currentTarget).find('i').data('guid'),
                             gType = "term";
                         Utils.setUrl({
                             url: '#!/glossary/' + guid,
@@ -322,7 +323,7 @@ define(['require',
                     this.renderRelationshipLayoutView(obj);
                     this.renderAuditTableLayoutView(obj);
                     this.renderTagTableLayoutView(obj);
-                    if (Globals.isTasksEnabled) { this.renderPendingTaskTableLayoutView(); }
+                    if (Globals.isTasksEnabled && Globals.isUiTasksTabEnabled) { this.renderPendingTaskTableLayoutView(); }
 
                     // To render profile tab check for attribute "profileData" or typeName = "hive_db","hbase_namespace"
                     if (collectionJSON && (!_.isUndefined(collectionJSON.attributes['profileData']) || collectionJSON.typeName === "hive_db" || collectionJSON.typeName === "hbase_namespace")) {
@@ -531,7 +532,7 @@ define(['require',
                     termData = "";
                 _.each(data, function(val) {
                     var glossaryName = val.qualifiedName ? val.qualifiedName : val.displayText;
-                    termData += '<span class="btn btn-action btn-sm btn-icon btn-blue" data-id="termClick" title= "' + glossaryName + '"><span>' + _.escape(glossaryName) + '</span><i class="' + (val.relationshipStatus == "ACTIVE" ? 'fa fa-close' : "") + '" data-id="deleteTerm" data-guid="' + val.guid + '" data-type="term" title="Remove Term"></i></span>';
+                    termData += '<span class="btn btn-action btn-sm btn-icon btn-blue" data-id="termClick" title= "' + _.escape(glossaryName) + '"><span>' + _.escape(glossaryName) + '</span><i class="' + (val.relationshipStatus == "ACTIVE" ? 'fa fa-close' : "") + '" data-id="deleteTerm" data-guid="' + val.guid + '" data-type="term" title="Remove Term"></i></span>';
                 });
                 this.ui.termList.find("span.btn").remove();
                 this.ui.termList.prepend(termData);
