@@ -52,7 +52,7 @@ define(['require',
              * @constructs
              */
             initialize: function(options) {
-                _.extend(this, _.pick(options, 'value', 'entityDefCollection', 'typeHeaders', 'searchVent', 'enumDefCollection', 'classificationDefCollection', 'businessMetadataDefCollection', 'tag', 'searchTableFilters'));
+                _.extend(this, _.pick(options, 'value', 'entityDefCollection', 'typeHeaders', 'searchVent', 'enumDefCollection', 'classificationDefCollection', 'businessMetadataDefCollection', 'tag', 'searchTableFilters', 'relationshipDefCollection', 'relationship'));
                 this.bindEvents();
                 var that = this;
                 this.modal = new Modal({
@@ -106,6 +106,16 @@ define(['require',
                     if (Globals[this.value.tag] || Globals[Enums.addOnClassification[0]]) {
                         obj['systemAttrArr'] = (Globals[this.value.tag] || Globals[Enums.addOnClassification[0]]).attributeDefs;
                     }
+                } else if (this.relationship) {
+                    obj['relationship'] = true;
+                    obj['attrObj'] = this.relationshipDefCollection.fullCollection.find({ name: this.value.relationshipName });
+                    if(obj.attrObj){
+                        obj.attrObj = Utils.getNestedSuperTypeObj({
+                            data: obj.attrObj.toJSON(),
+                            collection: this.relationshipDefCollection,
+                            attrMerge: true,
+                        });
+                    }
                 } else {
                     obj['type'] = true;
                     obj['attrObj'] = this.entityDefCollection.fullCollection.find({ name: this.value.type });
