@@ -29,8 +29,9 @@ define(['require',
     'utils/Messages',
     'utils/Enums',
     'utils/UrlLinks',
-    'platform'
-], function(require, Backbone, tableDragger, SearchResultLayoutViewTmpl, Modal, VEntity, Utils, Globals, VSearchList, VCommon, CommonViewFunction, Messages, Enums, UrlLinks, platform) {
+    'platform',
+    'collection/VDownloadList'
+], function(require, Backbone, tableDragger, SearchResultLayoutViewTmpl, Modal, VEntity, Utils, Globals, VSearchList, VCommon, CommonViewFunction, Messages, Enums, UrlLinks, platform, VDownloadList) {
     'use strict';
 
     var SearchResultLayoutView = Backbone.Marionette.LayoutView.extend(
@@ -72,7 +73,8 @@ define(['require',
                 gotoPagebtn: "[data-id='gotoPagebtn']",
                 activePage: "[data-id='activePage']",
                 excludeSubtypes: ".exclude-subtypes",
-                excludeSubClassifications: ".exclude-subclassifications"
+                excludeSubClassifications: ".exclude-subclassifications",
+                downloadResults: "[data-id='downloadSearchResult']"
             },
             templateHelpers: function() {
                 return {
@@ -80,7 +82,8 @@ define(['require',
                     searchType: this.searchType,
                     fromView: this.fromView,
                     isGlossaryView: this.fromView == "glossary",
-                    isSearchTab: Utils.getUrlState.isSearchTab()
+                    isSearchTab: Utils.getUrlState.isSearchTab(),
+                    isProfileDBView: this.options.profileDBView
                 };
             },
             /** ui events hash */
@@ -141,6 +144,7 @@ define(['require',
                 events["click " + this.ui.checkDeletedEntity] = 'onCheckExcludeIncludeResult';
                 events["click " + this.ui.checkSubClassification] = 'onCheckExcludeIncludeResult';
                 events["click " + this.ui.checkSubType] = 'onCheckExcludeIncludeResult';
+                events["click " + this.ui.downloadResults] = 'onDownloadSearchResults';
                 return events;
             },
             /**
@@ -148,9 +152,10 @@ define(['require',
              * @constructs
              */
             initialize: function(options) {
-                _.extend(this, _.pick(options, 'value', 'guid', 'initialView', 'isTypeTagNotExists', 'classificationDefCollection', 'entityDefCollection', 'typeHeaders', 'searchVent', 'enumDefCollection', 'tagCollection', 'searchTableColumns', 'isTableDropDisable', 'fromView', 'glossaryCollection', 'termName', 'businessMetadataDefCollection', 'profileDBView'));
+                _.extend(this, _.pick(options, 'value', 'guid', 'initialView', 'isTypeTagNotExists', 'classificationDefCollection', 'entityDefCollection', 'typeHeaders', 'searchVent', 'enumDefCollection', 'tagCollection', 'searchTableColumns', 'isTableDropDisable', 'fromView', 'glossaryCollection', 'termName', 'businessMetadataDefCollection', 'profileDBView', 'exportVent'));
                 this.entityModel = new VEntity();
                 this.searchCollection = new VSearchList();
+                this.downloadSearchResults = new VDownloadList();
                 this.limit = 25;
                 this.asyncFetchCounter = 0;
                 this.offset = 0;
@@ -158,6 +163,11 @@ define(['require',
                 this.multiSelectEntity = [];
                 this.activeEntityCountSelected = 0;
                 this.searchType = 'Basic Search';
+                this.tableColumnsLabelMap = {};
+                this.downloadSearchResultsParams = {
+                    searchParameters: {},
+                    attributeLabelMap: {}
+                };
                 this.columnOrder = null;
                 this.defaultColumns = ["selected", "name", "description", "typeName", "owner", "tag", "term"];
                 if (this.value) {
@@ -186,6 +196,7 @@ define(['require',
                 if (platform.name === "IE") {
                     this.isTableDropDisable = true;
                 }
+                this.businessMetadataAttributes = [];
             },
             bindEvents: function() {
                 var that = this;
@@ -241,6 +252,8 @@ define(['require',
                                 this.ui.columnEmptyInfo.hide();
                             }
                         }
+                        this.downloadSearchResultsParams.searchParameters.attributes = excludeDefaultColumn;
+                        this.validateAttributeLabelMap();
                         this.columnOrder = this.getColumnOrder(this.REntityTableLayoutView.$el.find('.colSort th.renderable'));
                         this.triggerUrl();
                         var attributes = this.searchCollection.filterObj.attributes;
@@ -514,6 +527,11 @@ define(['require',
                             }
                             that.$('.searchResult').html(searchString);
                         }
+                        if (dataOrCollection.approximateCount || dataOrCollection.length) {
+                            that.ui.downloadResults.show();
+                        } else {
+                            that.ui.downloadResults.hide();
+                        }
                     },
                     silent: true,
                     reset: true
@@ -564,6 +582,8 @@ define(['require',
                         Globals.searchApiCallRef = this.searchCollection.fetch(apiObj);
                     }
                 }
+                this.downloadSearchResultsParams.searchParameters = apiObj.data;
+                this.generateBusinessMetadataAttrList();
             },
             tableRender: function(options) {
                 var that = this,
@@ -648,6 +668,67 @@ define(['require',
                     that.checkTableFetch();
                 });
             },
+            generateAttributeLabelMap: function() {
+                var that = this,
+                    params = this.downloadSearchResultsParams;
+                if (params.searchParameters.attributes) {
+                    _.map(params.searchParameters.attributes, function(attr) {
+                        for (var label in that.tableColumnsLabelMap) {
+                            if (attr === that.tableColumnsLabelMap[label]) {
+                                params.attributeLabelMap[label] = that.tableColumnsLabelMap[label];
+                            }
+                        }
+                    });
+                }
+            },
+            validateAttributeLabelMap: function() {
+                var that = this,
+                    params = this.downloadSearchResultsParams;
+                if (params.searchParameters.attributes.length !== 0) {
+                    _.map(params.searchParameters.attributes, function(attr) {
+                        for (var key in params.attributeLabelMap) {
+                            if (params.attributeLabelMap[key] !== attr) {
+                                delete params.attributeLabelMap[key];
+                            }
+                        }
+                    });
+                } else {
+                    params.attributeLabelMap = {};
+                }
+            },
+            generateBusinessMetadataAttrList: function() {
+                var def = this.entityDefCollection.fullCollection.find({
+                        name: this.value.type,
+                    }),
+                    businessAttributeDefs,
+                    that = this;
+                businessAttributeDefs = def ? def.get('businessAttributeDefs') : null;
+                if (businessAttributeDefs) {
+                    _.each(
+                        businessAttributeDefs,
+                        function(businessMetadata, businessMetadataName) {
+                            _.each(businessMetadata, function(attr, index) {
+                                that.businessMetadataAttributes.push({
+                                    name: businessMetadataName + '.' + attr.name,
+                                    type: attr.typeName
+                                });
+                            });
+                        }
+                    );
+                }
+            },
+            checkIsEditorValue: function(key) {
+                var isEditorKey = false;
+                if (this.businessMetadataAttributes.length) {
+                    _.each(this.businessMetadataAttributes, function(attr) {
+                        if (attr.name === key && attr.type === "string") {
+                            isEditorKey = true;
+                            return;
+                        };
+                    });
+                }
+                return isEditorKey;
+            },
             getColumnOrder: function(arr) {
                 var obj = {};
                 for (var i = 0; i < arr.length; ++i) {
@@ -699,6 +780,7 @@ define(['require',
                     resizeable: true,
                     orderable: false,
                     renderable: true,
+                    sortable: true,
                     className: "searchTableName",
                     formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                         fromRaw: function(rawValue, model) {
@@ -771,6 +853,7 @@ define(['require',
                     resizeable: true,
                     orderable: true,
                     renderable: true,
+                    sortable: true,
                     formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                         fromRaw: function(rawValue, model) {
                             var obj = model.toJSON();
@@ -785,6 +868,7 @@ define(['require',
                         label: "Date Created",
                         cell: "Html",
                         editable: false,
+                        sortable: true,
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
                                 var obj = model.toJSON();
@@ -805,6 +889,7 @@ define(['require',
                         resizeable: true,
                         orderable: true,
                         renderable: true,
+                        sortable: true,
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
                                 var obj = model.toJSON();
@@ -822,6 +907,7 @@ define(['require',
                         editable: false,
                         resizeable: true,
                         orderable: true,
+                        sortable: true,
                         renderable: (columnToShow ? _.contains(columnToShow, 'typeName') : true),
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
@@ -884,7 +970,9 @@ define(['require',
                             _.each(attrObj, function(obj, key) {
                                 var key = obj.name,
                                     isRenderable = _.contains(columnToShow, key),
-                                    isSortable = obj.typeName.search(/(array|map)/i) == -1;
+                                    // isSortable = obj.typeName.search(/(array|map)/i) == -1, // commented : as sorting is required for all the columns except classifications and terms
+                                    isSortable = obj.typeName.search(/(string|date|boolean|int|number|byte|float|long|double|short)/i) == 0, // commented : as sorting is required for all the columns except non-primitive types
+                                    columnLabel;
                                 if (key == "name" || key == "description" || key == "owner") {
                                     if (columnToShow) {
                                         col[key].renderable = isRenderable;
@@ -894,10 +982,12 @@ define(['require',
                                 if (key == "__historicalGuids" || key == "__classificationsText" || key == "__classificationNames" || key == "__propagatedClassificationNames") {
                                     return;
                                 }
+                                columnLabel = Enums.systemAttributes[obj.name] ? Enums.systemAttributes[obj.name] : (_.escape(obj.isBusinessAttributes ? obj.name : obj.name.capitalize()));
+                                that.tableColumnsLabelMap[columnLabel] = obj.name;
                                 col[obj.name] = {
-                                    label: Enums.systemAttributes[obj.name] ? Enums.systemAttributes[obj.name] : (_.escape(obj.isBusinessAttributes ? obj.name : obj.name.capitalize())),
+                                    label: columnLabel,
                                     cell: "Html",
-                                    headerCell: Backgrid.HeaderHTMLDecodeCell,
+                                    // headerCell: Backgrid.HeaderHTMLDecodeCell,
                                     editable: false,
                                     resizeable: true,
                                     orderable: true,
@@ -937,6 +1027,7 @@ define(['require',
                                                     }
                                                 }
                                                 tempObj.valueObject[key] = modelObj.attributes[key];
+                                                tempObj['isEditorValue'] = that.checkIsEditorValue(key);
                                                 var tablecolumn = CommonViewFunction.propertyTable(tempObj);
                                                 if (_.isArray(modelObj.attributes[key])) {
                                                     var column = $("<div>" + tablecolumn + "</div>")
@@ -1009,6 +1100,7 @@ define(['require',
                                             'valueObject': {},
                                             'isTable': false
                                         };
+                                        tempObj['isEditorValue'] = that.checkIsEditorValue(key);
                                         tempObj.valueObject[key] = modelObj[key];
                                         return CommonViewFunction.propertyTable(tempObj);
                                     }
@@ -1301,6 +1393,32 @@ define(['require',
                 this.fetchCollection();
 
             },
+            onDownloadSearchResults: function() {
+                this.generateAttributeLabelMap();
+                Utils.disableRefreshButton(this.ui.downloadResults, this);
+                if (this.value.searchType !== "basic") {
+                    this.downloadSearchResultsParams.searchParameters = {
+                        "limit": this.limit,
+                        "offset": this.offset,
+                        "query": this.value.query || null,
+                        "typeName": this.value.type || null
+                    };
+                    delete this.downloadSearchResultsParams.attributeLabelMap;
+                }
+                var apiObj = {
+                    sort: false,
+                    data: this.downloadSearchResultsParams,
+                    success: function(model, response) {
+                        Utils.notifySuccess({
+                            content: "The current search results have been enqueued for download. You can access the csv file by clicking the large arrow icon at the top of the page."
+                        });
+                    },
+                    reset: true,
+                    complete: function() {},
+                    error: function(error) {}
+                }
+                this.downloadSearchResults.startDownloading(apiObj);
+            },
             changePageLimit: function(e, obj) {
                 if (!obj || (obj && !obj.skipViewChange)) {
                     var limit = parseInt(this.ui.showPage.val());
