@@ -82,10 +82,6 @@ require.config({
         'jquery-ui': {
             'deps': ['jquery']
         },
-        'asBreadcrumbs': {
-            'deps': ['jquery'],
-            'exports': 'asBreadcrumbs'
-        },
         'bootstrap': {
             'deps': ['jquery'],
             'exports': 'jquery'
@@ -187,7 +183,6 @@ require.config({
         'backgrid-paginator': 'libs/backgrid-paginator/js/backgrid-paginator.min',
         'backgrid-sizeable': 'libs/backgrid-sizeable-columns/js/backgrid-sizeable-columns',
         'backgrid-columnmanager': 'external_lib/backgrid-columnmanager/js/Backgrid.ColumnManager',
-        'asBreadcrumbs': 'libs/jquery-asBreadcrumbs/js/jquery-asBreadcrumbs.min',
         'd3': 'libs/d3/d3.min',
         'd3-tip': 'libs/d3/index',
         'LineageHelper': 'external_lib/atlas-lineage/dist/index',
@@ -289,6 +284,19 @@ require(['App',
             App.start();
         }
     };
+    var relationshipSearch= function(){
+        var that=this;
+        this.relationshipDefCollection.fetch({
+            async: true,
+            complete: function() {
+                that.relationshipDefCollection.fullCollection.comparator = function(model) {
+                    return model.get('name').toLowerCase();
+                };
+                that.relationshipDefCollection.fullCollection.sort({ silent: true });
+                startApp();
+            }
+        });
+    };
     CommonViewFunction.userDataFetch({
         url: UrlLinks.sessionApiUrl(),
         callback: function(response) {
@@ -318,6 +326,7 @@ require(['App',
                 }
                 if (response['atlas.ui.date.format'] !== undefined) {
                     Globals.dateTimeFormat = response['atlas.ui.date.format'];
+                    if (Globals.dateTimeFormat.toLocaleLowerCase().indexOf("dd") == 0) Globals.needToValidateDate = true;
                     var dateFormatSeperated = Globals.dateTimeFormat.split(' ');
                     if (dateFormatSeperated[0]) {
                         Globals.dateFormat = dateFormatSeperated[0]; //date
@@ -332,13 +341,22 @@ require(['App',
                 if (response['atlas.tasks.enabled'] !== undefined) {
                     Globals.isTasksEnabled = response['atlas.tasks.enabled'];
                 }
+                if (response['atlas.tasks.ui.tab.enabled'] !== undefined) {
+                    Globals.isUiTasksTabEnabled = response['atlas.tasks.ui.tab.enabled'];
+                }
                 if (response['atlas.session.timeout.secs']) { Globals.idealTimeoutSeconds = response['atlas.session.timeout.secs']; }
-                if(response['atlas.lineage.on.demand.enabled'] !== undefined){
+                if (response['atlas.lineage.on.demand.enabled'] !== undefined) {
                     Globals.isLineageOnDemandEnabled = response['atlas.lineage.on.demand.enabled'];
                 }
-                if(response['atlas.lineage.on.demand.default.node.count'] !== undefined){
+                if (response['atlas.lineage.on.demand.default.node.count'] !== undefined) {
                     Globals.lineageNodeCount = response['atlas.lineage.on.demand.default.node.count'];
                 }
+                if (response['atlas.relationship.search.enabled'] !== undefined) {
+                    Globals.isRelationshipSearchEnabled = response['atlas.relationship.search.enabled'];
+                }
+                if(Globals.isRelationshipSearchEnabled){
+                    relationshipSearch();
+                }
                 /*  Atlas idealTimeout 
        redirectUrl: url to redirect after timeout
        idealTimeLimit: timeout in seconds
@@ -425,7 +443,7 @@ require(['App',
         }
     });
     this.relationshipDefCollection.fetch({
-        async:true,
+        async: true,
         complete: function() {
             that.relationshipDefCollection.fullCollection.comparator = function(model) {
                 return model.get('name').toLowerCase();
