@@ -49,10 +49,12 @@ define(["require", "underscore"], function(require, _) {
     // Date Format
     Globals.dateTimeFormat = "MM/DD/YYYY hh:mm:ss A";
     Globals.dateFormat = "MM/DD/YYYY";
+    Globals.needToValidateDate = false;
     Globals.isTimezoneFormatEnabled = true;
 
     Globals.isDebugMetricsEnabled = false;
     Globals.isTasksEnabled = false;
+    Globals.isUiTasksTabEnabled = false;
     Globals.advanceSearchData = {};
     Globals.idealTimeoutSeconds = 900;
     Globals.isFullScreenView = false;
@@ -60,6 +62,7 @@ define(["require", "underscore"], function(require, _) {
     Globals.lineageNodeCount = 3;
     Globals.lineageDepth = 3;
     Globals.fromRelationshipSearch = false;
+    Globals.isRelationshipSearchEnabled = false;
 
     return Globals;
 });
\ No newline at end of file
