@@ -957,6 +957,16 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
         $(this).removeClass('button-loader').removeAttr("disabled");
         $(this).siblings("button.cancel").prop("disabled", false);
     }
+    Utils.convertToValidDate = function(dateValue) {
+        var value = dateValue.split(" "),
+            dateSplit = (value[0].indexOf("-") == -1) ? value[0].split("/") : value[0].split("-");
+        if (value.length > 1) {
+            var time = value[1].split(":");
+            return new Date(dateSplit[2], (new Number(dateSplit[1]) - 1), dateSplit[0], time[0], time[1], time[2]);
+        } else {
+            return new Date(dateSplit[2], (new Number(dateSplit[1]) - 1), dateSplit[0]);
+        }
+    }
     Utils.formatDate = function(options) {
         var dateValue = null,
             dateFormat = Globals.dateTimeFormat,
@@ -1301,20 +1311,35 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
             $parent.css('border', '1px solid #8fa5b1');
         }).on('tbwchange', function(e) {
             options.callback ? options.callback(e) : null;
+            e.target.value = Utils.sanitizeHtmlContent({ data: e.target.value });
         }).on('tbwmodalopen', function(e) {
             $('input[name="title"], input[name="target"]').parent().css('display', 'none');
         });
     }
 
     Utils.sanitizeHtmlContent = function(options) {
-        var editorContent, cleanedContent;
+        var editorContent, cleanedContent,
+            config = {
+                ALLOWED_TAGS: ['b', 'em', 'strong', 'u', 'a', 'ul', 'ol', 'li', 'p', 'strike', 'h1', 'h2', 'h3', 'h4'],
+                ALLOWED_ATTR: ['href'],
+                FORBID_TAGS: ['script', 'img', 'iframe', 'svg', 'title'],
+                FORBID_ATTR: ['onmouseover', 'onload', 'onclick', 'onerror', 'src']
+            };
         editorContent = options.selector ? $(options.selector).trumbowyg('html') : options.data;
         if (options && editorContent) {
-            cleanedContent = DOMPurify.sanitize(editorContent, { FORBID_TAGS: ['img', 'script', 'iframe', 'embed', 'svg', 'meta'], ALLOWED_ATTR: ['target', 'href'] });
+            cleanedContent = DOMPurify.sanitize(editorContent, config);
         }
-        return cleanedContent;
+        return cleanedContent || "";
     }
     //-----------------------------------------END---------------------//
 
+    Utils.disableRefreshButton = function(el, that) {
+        var that = that;
+        el.attr('disabled', true);
+        setTimeout(function() {
+            el.attr('disabled', false);
+        }, 1000);
+    }
+
     return Utils;
-});
+});
\ No newline at end of file
