@@ -520,6 +520,7 @@ define(['require',
                     resizeable: true,
                     orderable: false,
                     renderable: true,
+                    sortable: false,
                     className: "searchTableName",
                     formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                         fromRaw: function(rawValue, model) {
@@ -553,6 +554,7 @@ define(['require',
                         editable: false,
                         resizeable: true,
                         orderable: true,
+                        sortable: true,
                         renderable: (columnToShow ? _.contains(columnToShow, 'typeName') : true),
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
@@ -569,6 +571,7 @@ define(['require',
                         editable: false,
                         resizeable: true,
                         orderable: true,
+                        sortable: false,
                         renderable: (columnToShow ? _.contains(columnToShow, 'end1') : true),
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
@@ -579,7 +582,7 @@ define(['require',
                                         uniqueAttributesValue = obj.end1.uniqueAttributes[key];
                                     }
                                     uniqueAttributesValue  = uniqueAttributesValue ? uniqueAttributesValue : obj.end1.guid;
-                                    return '<a title="' + uniqueAttributesValue + '" href="#!/detailPage/' + obj.end1.guid  + '?from=relationshipSearch">' + uniqueAttributesValue + '</a>';
+                                    return '<a title="' + _.escape(uniqueAttributesValue) + '" href="#!/detailPage/' + obj.end1.guid  + '?from=relationshipSearch">' + _.escape(uniqueAttributesValue) + '</a>';
                                 }
                             }
                         })
@@ -590,6 +593,7 @@ define(['require',
                         editable: false,
                         resizeable: true,
                         orderable: true,
+                        sortable: false,
                         renderable: (columnToShow ? _.contains(columnToShow, 'end2') : true),
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
@@ -600,7 +604,7 @@ define(['require',
                                         uniqueAttributesValue = obj.end2.uniqueAttributes[key];
                                     }
                                     uniqueAttributesValue  = uniqueAttributesValue ? uniqueAttributesValue : obj.end2.guid;
-                                    return '<a title="' + uniqueAttributesValue + '" href="#!/detailPage/' + obj.end2.guid  + '?from=relationshipSearch">' + uniqueAttributesValue + '</a>';
+                                    return '<a title="' + _.escape(uniqueAttributesValue) + '" href="#!/detailPage/' + obj.end2.guid  + '?from=relationshipSearch">' + _.escape(uniqueAttributesValue) + '</a>';
                                 }
                             }
                         })
@@ -611,6 +615,7 @@ define(['require',
                         editable: false,
                         resizeable: true,
                         orderable: true,
+                        sortable: true,
                         renderable: (columnToShow ? _.contains(columnToShow, 'label') : true),
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
@@ -626,14 +631,16 @@ define(['require',
                         var def = this.relationshipDefCollection.fullCollection.find({ name: this.value.relationshipName });
                         if (def) {
                             var attrObj = def ? Utils.getNestedSuperTypeObj({ data: def.toJSON(), collection: this.relationshipDefCollection, attrMerge: true }) : [];
-                            _.each(attrObj, function(obj, key) {
-                                var key = obj.name,
+                            _.each(attrObj, function(obj) {
+                                var key = _.escape(obj.name),
                                     isRenderable = _.contains(columnToShow, key),
-                                    isSortable = obj.typeName.search(/(array|map)/i) == -1;
-                                col[obj.name] = {
-                                    label: obj.name.capitalize(),
+                                    // isSortable = obj.typeName.search(/(array|map)/i) == -1;
+                                    isSortable = obj.typeName.search(/(string|date|boolean|int|number|byte|float|long|double|short)/i) == 0; // commented : as sorting is required for all the columns except non-primitive types
+
+                                col[key] = {
+                                    label: key.capitalize(),
                                     cell: "Html",
-                                    headerCell: Backgrid.HeaderHTMLDecodeCell,
+                                    // headerCell: Backgrid.HeaderHTMLDecodeCell,
                                     editable: false,
                                     resizeable: true,
                                     orderable: true,
