@@ -110,7 +110,7 @@ define(['require',
          * @constructs
          */
         initialize: function(options) {
-            _.extend(this, _.pick(options, 'modalCollection', 'guid', 'callback', 'multiple', 'showLoader', 'hideLoader', 'tagList', 'tagModel', 'enumDefCollection'));
+            _.extend(this, _.pick(options, 'modalCollection', 'guid', 'callback', 'multiple', 'entityCount', 'showLoader', 'hideLoader', 'tagList', 'tagModel', 'enumDefCollection'));
             this.commonCollection = new VTagList();
             if (this.tagModel) {
                 this.collection = new Backbone.Collection(this.tagModel.validityPeriods);
@@ -136,6 +136,14 @@ define(['require',
             this.modal.open();
             this.modal.$el.find('button.ok').attr("disabled", true);
             this.on('ok', function() {
+                if (this.ui.checkTimeZone.is(':checked')) {
+                    if (this.validateValues()) {
+                        if (this.hideLoader) {
+                            this.hideLoader();
+                        };
+                        return;
+                    };
+                }
                 that.modal.$el.find('button.ok').showButtonLoader();
                 var tagName = this.tagModel ? this.tagModel.typeName : this.ui.addTagOptions.val(),
                     tagAttributes = {},
@@ -146,14 +154,32 @@ define(['require',
                         guid: [],
                         skipEntity: [],
                         deletedEntity: []
-                    };
+                    },
+                    isValidateAttrValue = true,
+                    validationKey = [];
                 tagAttributeNames.each(function(i, item) {
-                    var selection = $(item).data("key");
-                    var datatypeSelection = $(item).data("type");
+                    var selection = $(item).data("key"),
+                        isRequired = $(item).hasClass('required'),
+                        datatypeSelection = $(item).data("type"),
+                        $valueElement = $(item);
+                    $valueElement.removeClass('errorValidate');
                     if (datatypeSelection === "date") {
-                        tagAttributes[selection] = Date.parse($(item).val()) || null;
-                    } else {
-                        tagAttributes[selection] = $(item).val() || null;
+                        var convertedDate = Globals.needToValidateDate ? Utils.convertToValidDate($valueElement.val()) : $valueElement.val();
+                        tagAttributes[selection] = Date.parse(convertedDate) || null;
+                    }  else {
+                        if (isRequired) {
+                            if ($valueElement.val().length) {
+                                tagAttributes[selection] = $(item).val() || null;
+                                // tagAttributes[selection] = that.getValue($valueElement, datatypeSelection);
+                            } else {
+                                isValidateAttrValue = false;
+                                $valueElement.addClass('errorValidate');
+                                validationKey.push($(item).data("key"));
+                            }
+                        } else {
+                            tagAttributes[selection] = $(item).val() || null;
+                            // tagAttributes[selection] = that.getValue($valueElement, datatypeSelection);
+                        }
                     }
                 });
 
@@ -177,6 +203,7 @@ define(['require',
                                 "</b> " + (obj.deletedEntity.length === 1 ? "entity " : "entities ") +
                                 Messages.assignDeletedEntity
                         });
+                        that.modal.close();
                     }
                     if (obj.skipEntity.length) {
                         var text = "<b>" + obj.skipEntity.length + " of " + that.multiple.length +
@@ -237,6 +264,18 @@ define(['require',
                             that.hideLoader();
                         }
                     }
+                } else if (isValidateAttrValue === false) {
+                    var validationMsg = "" + _.each(validationKey, function(key) {
+                        return key + " ";
+                    });
+                    that.modal.$el.find('button.ok').hideButtonLoader();
+                    Utils.notifyInfo({
+                        content: "Value for " + validationMsg + " cannot be empty"
+                    });
+                    if (this.hideLoader) {
+                        this.hideLoader();
+                    };
+                    return;
                 } else {
                     obj.guid.push(that.guid);
                     that.saveTagData(obj);
@@ -247,6 +286,50 @@ define(['require',
             });
             this.bindEvents();
         },
+        getValue: function($item, datatypeSelection) {
+            var that = this;
+            return (datatypeSelection && datatypeSelection.indexOf("array") >= 0) ? that.getArrayValues($item) : ($item.val() || null);
+        },
+        getArrayValues: function($item) {
+            var that = this,
+                arrayValues = $item.val();
+            if ($item.hasClass("set-array") || arrayValues.length == 0) {
+                return (arrayValues || null);
+            } else {
+                return _.map(arrayValues, function(value) {
+                    var splitBy = that.guid + "_",
+                        splitedValue = value.split(splitBy);
+                    return (splitedValue.length > 1) ? splitedValue[1] : splitedValue[0];
+                })
+            }
+        },
+        validateValues: function(attributeDefs) {
+            var isValidate = true,
+                applyErrorClass = function(scope) {
+                    if (this.value == '' || this.value == null || this.value.indexOf('Select Timezone') > -1) {
+                        $(this).addClass('errorValidate');
+                        if (isValidate) { isValidate = false; }
+                    } else {
+                        $(this).removeClass('errorValidate');
+                    }
+                };
+
+            this.$el.find('.start-time').each(function(element) {
+                applyErrorClass.call(this);
+            });
+            this.$el.find('.end-time').each(function(element) {
+                applyErrorClass.call(this);
+            });
+            this.$el.find('.time-zone').each(function(element) {
+                applyErrorClass.call(this);
+            });
+            if (!isValidate) {
+                Utils.notifyInfo({
+                    content: "Please fill the details"
+                });
+                return true;
+            }
+        },
 
         onRender: function() {
             var that = this;
@@ -349,7 +432,9 @@ define(['require',
             if (attributeDefs) {
                 _.each(attributeDefs, function(obj) {
                     var name = Utils.getName(obj, 'name');
-                    var typeName = Utils.getName(obj, 'typeName');
+                    var typeName = Utils.getName(obj, 'typeName'),
+                        isOptional = obj.isOptional,
+                        inputClassName = "form-control attributeInputVal attrName" + (isOptional ? "" : " required");
                     var typeNameValue = that.enumDefCollection.fullCollection.findWhere({ 'name': typeName });
                     if (typeNameValue) {
                         var str = '<option value=""' + (!that.tagModel ? 'selected' : '') + '>-- Select ' + typeName + " --</option>";
@@ -357,12 +442,17 @@ define(['require',
                         _.each(enumValue, function(key, value) {
                             str += '<option ' + ((that.tagModel && key.value === that.tagModel.attributes[name]) ? 'selected' : '') + '>' + _.escape(key.value) + '</option>';
                         })
-                        that.ui.tagAttribute.append('<div class="form-group"><label>' + name + '</label>' + ' (' + typeName + ')' +
-                            '<select class="form-control attributeInputVal attrName" data-key="' + name + '">' + str + '</select></div>');
+                        that.ui.tagAttribute.append('<div class="form-group"><label class="' + (isOptional ? "" : " required") + '">' + name + '</label>' + ' (' + typeName + ')' +
+                            '<select class="' + inputClassName + '" data-key="' + name + '">' + str + '</select></div>');
+                    } else if (typeName.indexOf('array') == 0) {
+                        var arraytTypeName = new DOMParser().parseFromString(typeName, "text/html");
+                        var addCardinalityClass = inputClassName + " js-states js-example-events form-control" + (obj.cardinality == "SET" ? " set-array" : " list-array");
+                        that.ui.tagAttribute.append('<div class="form-group"><label class="' + (isOptional ? "" : " required") + '">' + name + '</label>' + ' (' + typeName + ') ' + obj.cardinality +
+                            '<select class="' + addCardinalityClass + '" data-id="addArryString" multiple="multiple" data-key="' + name + '" data-type="' + arraytTypeName.documentElement.textContent + '"></select></div>');
                     } else {
-                        var textElement = that.getElement(name, typeName);
+                        var textElement = that.getElement(name, typeName, inputClassName);
                         if (_.isTypePrimitive(typeName)) {
-                            that.ui.tagAttribute.append('<div class="form-group"><label>' + name + '</label>' + ' (' + typeName + ')' + textElement + '</div>');
+                            that.ui.tagAttribute.append('<div class="form-group"><label class="' + (isOptional ? "" : " required") + '">' + name + '</label>' + ' (' + typeName + ')' + textElement + '</div>');
                         }
                     }
                 });
@@ -372,13 +462,16 @@ define(['require',
                             "singleDatePicker": true,
                             "showDropdowns": true,
                             "timePicker": true,
+                            startDate: new Date(),
                             locale: {
                                 format: Globals.dateTimeFormat
                             }
                         };
                         if (that.tagModel) {
-                            var formatDate = Number(this.value);
-                            dateObj["startDate"] = new Date(formatDate);
+                            if (this.value.length) {
+                                var formatDate = Number(this.value);
+                                dateObj["startDate"] = new Date(formatDate);
+                            }
                         }
                         $(this).daterangepicker(dateObj);
                     }
@@ -389,25 +482,87 @@ define(['require',
                         this.value = that.tagModel.attributes[labelName];
                     }
                 });
+                that.$('select[data-type="array<string>"]').each(function() {
+                    var stringData = $(this).data('key'),
+                        self = this;
+                    if (that.tagModel) {
+                        var stringValues = that.tagModel.attributes[stringData] || [],
+                            str = stringValues.map(function(label) {
+                                // var id = ($(self).hasClass("list-array")) ? ("" + Utils.generateUUID() + that.guid + "_" + label + "") : ("" + label + "");
+                                // return ($(self).hasClass("list-array")) ? "<option selected value=" + id + "> " + _.escape(label) + " </option>" : "<option selected> " + _.escape(label) + " </option>";
+                                return "<option selected> " + _.escape(label) + " </option>";
+                            });
+                        $(this).html(str);
+                    }
+                    var getLabelData = function(data, selectedData) {
+                        if (data.suggestions.length) {
+                            return _.map(data.suggestions, function(name, index) {
+                                var findValue = _.find(selectedData, { id: name })
+                                if (findValue) {
+                                    return findValue;
+                                } else {
+                                    return {
+                                        id: name,
+                                        text: name
+                                    }
+                                }
+                            });
+                        } else {
+                            var findValue = _.find(selectedData, { id: data.prefixString })
+                            return findValue ? [findValue] : [];
+                        }
+                    };
+                    $(this).select2({
+                            tags: true,
+                            multiple: true,
+                            createTag: function(data) {
+                                // var isSET = this.$element.hasClass("set-array"),
+                                //     found = _.find(this.$element.select2("data"), { id: data.term });
+                                // if (isSET) {
+                                //     if (!found) {
+                                //         return { id: data.term, text: data.term };
+                                //     }
+                                // } else {
+                                //     return { id: data.term, text: data.term };
+                                // }
+                                var found = _.find(this.$element.select2("data"), { id: data.term });
+                                if (!found) {
+                                    return { id: data.term, text: data.term };
+                                }
+                            },
+                            templateResult: that.formatResultSearch
+                        })
+                        // .on("select2:select", function(e) {
+                        //     if ($(this).hasClass("list-array")) { //allow duplicates value for list
+                        //         var options = $(this).find("option"),
+                        //             id = "" + Utils.generateUUID() + that.guid + "_" + e.params.data.text + "";
+                        //         $(self).append('<option value="' + id + '">' + e.params.data.text + '</option>');
+                        //     }
+                        // })
+                });
                 this.showAttributeBox();
             }
         },
-        getElement: function(labelName, typeName) {
+        formatResultSearch: function(state) {
+            if (state.text.trim() == "") return;
+            if (!state.id) return $("<span>Add<strong> '" + _.escape(state.text) + "'</strong></span>");;
+            // if (state.element && state.element.selected) return;
+            return $("<span>Add<strong> '" + _.escape(state.text) + "'</strong></span>");
+        },
+        getElement: function(labelName, typeName, inputClassName) {
             var value = this.tagModel && this.tagModel.attributes ? (this.tagModel.attributes[_.unescape(labelName)] || "") : "",
-                isTypeNumber = typeName === "int" || typeName === "byte" || typeName === "short" || typeName === "double" || typeName === "float",
-                inputClassName = "form-control attributeInputVal attrName";
+                isTypeNumber = typeName === "int" || typeName === "byte" || typeName === "short" || typeName === "double" || typeName === "float";
             if (isTypeNumber) {
                 inputClassName += ((typeName === "int" || typeName === "byte" || typeName === "short") ? " number-input-negative" : " number-input-exponential");
             }
             if (typeName === "boolean") {
-                return '<select class="form-control attributeInputVal attrName" data-key="' + labelName + '" data-type="' + typeName + '"> ' +
+                return '<select class="' + inputClassName + '" data-key="' + labelName + '" data-type="' + typeName + '"> ' +
                     '<option value="">--Select true or false--</option>' +
                     '<option value="true">true</option>' +
                     '<option value="false">false</option></select>';
             } else {
                 return '<input type="text" value="' + _.escape(value) + '" class="' + inputClassName + '" data-key="' + labelName + '" data-type="' + typeName + '"/>';
             }
-
         },
         checkTimezoneProperty: function(e) {
             if (e.checked) {
@@ -448,7 +603,7 @@ define(['require',
                 success: function(data) {
                     var addupdatetext = that.tagModel ? 'updated successfully to ' : 'added to ';
                     Utils.notifySuccess({
-                        content: "Classification " + tagName + " has been " + addupdatetext + (that.multiple ? "entities" : "entity")
+                        content: "Classification " + tagName + " has been " + addupdatetext + (that.entityCount > 1 ? "entities" : "entity")
                     });
                     if (options.modalCollection) {
                         options.modalCollection.fetch({ reset: true });
@@ -456,13 +611,15 @@ define(['require',
                     if (that.callback) {
                         that.callback();
                     }
-                    that.modal.close();
                 },
                 cust_error: function(model, response) {
                     that.modal.$el.find('button.ok').hideButtonLoader();
                     if (that.hideLoader) {
                         that.hideLoader();
                     }
+                },
+                complete: function() {
+                    that.modal.close();
                 }
             });
         },
