@@ -21,6 +21,7 @@ package org.apache.atlas.repository.graphdb.janus;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.ImmutableMap;
 import org.apache.atlas.ApplicationProperties;
+import org.apache.atlas.AtlasConfiguration;
 import org.apache.atlas.AtlasException;
 import org.apache.atlas.repository.graphdb.AtlasGraph;
 import org.apache.atlas.repository.graphdb.GraphDatabase;
@@ -38,6 +39,7 @@ import org.janusgraph.core.schema.JanusGraphManagement;
 import org.janusgraph.diskstorage.StandardIndexProvider;
 import org.janusgraph.diskstorage.StandardStoreManager;
 import org.janusgraph.diskstorage.es.ElasticSearch7Index;
+import org.janusgraph.diskstorage.hbase.HBaseStoreManager;
 import org.janusgraph.diskstorage.solr.Solr6Index;
 import org.janusgraph.graphdb.database.serialize.attribute.SerializableSerializer;
 import org.janusgraph.graphdb.tinkerpop.JanusGraphIoRegistry;
@@ -77,16 +79,14 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
     public static final String INDEX_BACKEND_ES           = "elasticsearch";
     public static final String GRAPH_TX_LOG_CONF          = "tx.log-tx";
     public static final String GRAPH_TX_LOG_VERBOSE_CONF  = "tx.recovery.verbose";
-    public static final String SOLR_INDEX_TX_LOG_TTL_CONF = "write.ahead.log.ttl.in.hours";
     public static final String GRAPH_TX_LOG_TTL_CONF      = "log.tx.ttl";
-    public static final long   DEFAULT_GRAPH_TX_LOG_TTL   = 72; //Hrs
 
     private static volatile AtlasJanusGraph atlasGraphInstance = null;
     private static volatile JanusGraph graphInstance;
 
     public AtlasJanusGraphDatabase() {
         //update registry
-        GraphSONMapper.build().addRegistry(JanusGraphIoRegistry.getInstance()).create();
+        GraphSONMapper.build().addRegistry(JanusGraphIoRegistry.instance()).create();
     }
 
     public static Configuration getConfiguration() throws AtlasException {
@@ -137,11 +137,11 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
             modifiersField.setInt(field, field.getModifiers() & ~Modifier.FINAL);
 
             Map<String, String> customMap = new HashMap<>(StandardStoreManager.getAllManagerClasses());
-            customMap.put("hbase2", org.janusgraph.diskstorage.hbase2.HBaseStoreManager.class.getName());
+            customMap.put("hbase2", HBaseStoreManager.class.getName());
             ImmutableMap<String, String> immap = ImmutableMap.copyOf(customMap);
             field.set(null, immap);
 
-            LOG.debug("Injected HBase2 support - {}", org.janusgraph.diskstorage.hbase2.HBaseStoreManager.class.getName());
+            LOG.debug("Injected HBase2 support - {}", HBaseStoreManager.class.getName());
         } catch (Exception e) {
             throw new RuntimeException(e);
         }
@@ -233,7 +233,7 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
     public static void configureTxLogBasedIndexRecovery() {
         try {
             boolean  recoveryEnabled = ApplicationProperties.get().getBoolean(INDEX_RECOVERY_CONF, DEFAULT_INDEX_RECOVERY);
-            long     ttl             = ApplicationProperties.get().getLong(SOLR_INDEX_TX_LOG_TTL_CONF, DEFAULT_GRAPH_TX_LOG_TTL);
+            long     ttl             = AtlasConfiguration.SOLR_INDEX_TX_LOG_TTL_CONF.getLong();
             Duration txLogTtlSecs    = Duration.ofSeconds(Duration.ofHours(ttl).getSeconds());
 
             Map<String, Object> properties = new HashMap<String, Object>() {{
