@@ -18,6 +18,7 @@
 package org.apache.atlas.repository.graphdb.janus;
 
 import com.google.common.annotations.VisibleForTesting;
+import org.apache.atlas.ApplicationProperties;
 import org.apache.atlas.exception.AtlasBaseException;
 import org.apache.atlas.model.discovery.AtlasAggregationEntry;
 import org.apache.atlas.repository.Constants;
@@ -40,16 +41,24 @@ import org.apache.solr.client.solrj.request.V2Request;
 import org.apache.solr.client.solrj.response.FacetField;
 import org.apache.solr.client.solrj.response.QueryResponse;
 import org.apache.solr.client.solrj.response.TermsResponse;
-import org.apache.solr.client.solrj.util.ClientUtils;
 import org.apache.solr.common.params.CommonParams;
-import org.apache.solr.common.util.ContentStream;
 import org.apache.solr.common.util.NamedList;
+import org.janusgraph.diskstorage.es.ElasticSearch7Index;
+import org.janusgraph.diskstorage.es.ElasticSearchClient;
 import org.janusgraph.diskstorage.solr.Solr6Index;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.PriorityQueue;
+import java.util.Set;
 
 import static org.apache.atlas.repository.Constants.FREETEXT_REQUEST_HANDLER;
 import static org.apache.atlas.repository.Constants.VERTEX_INDEX;
@@ -57,11 +66,15 @@ import static org.apache.atlas.repository.Constants.VERTEX_INDEX;
 public class AtlasJanusGraphIndexClient implements AtlasGraphIndexClient {
     private static final Logger LOG = LoggerFactory.getLogger(AtlasJanusGraphIndexClient.class);
 
-    private static final FreqComparator FREQ_COMPARATOR          = new FreqComparator();
-    private static final int            DEFAULT_SUGGESTION_COUNT = 5;
-    private static final int            MIN_FACET_COUNT_REQUIRED = 1;
-    private static final String         TERMS_PREFIX             = "terms.prefix";
-    private static final String         TERMS_FIELD              = "terms.fl";
+    private static final FreqComparator FREQ_COMPARATOR              = new FreqComparator();
+    private static final int            DEFAULT_SUGGESTION_COUNT     = 5;
+    private static final int            MIN_FACET_COUNT_REQUIRED     = 1;
+    private static final String         TERMS_PREFIX                 = "terms.prefix";
+    private static final String         TERMS_FIELD                  = "terms.fl";
+    private static final int            SOLR_HEALTHY_STATUS          = 0;
+    private static final long           SOLR_STATUS_LOG_FREQUENCY_MS = 60000;//Prints SOLR DOWN status for every 1 min
+    private static       long           prevIdxHealthCheckTime;
+
 
     private final Configuration configuration;
 
@@ -70,6 +83,34 @@ public class AtlasJanusGraphIndexClient implements AtlasGraphIndexClient {
         this.configuration = configuration;
     }
 
+    public boolean isHealthy() {
+        boolean isHealthy   = false;
+        long    currentTime = System.currentTimeMillis();
+        String  idxBackEnd  = configuration.getString(ApplicationProperties.INDEX_BACKEND_CONF);
+
+        try {
+            if (ApplicationProperties.INDEX_BACKEND_SOLR.equals(idxBackEnd)) {
+                isHealthy = isSolrHealthy();
+            } else if (ApplicationProperties.INDEX_BACKEND_ELASTICSEARCH.equals(idxBackEnd)) {
+                isHealthy = isElasticsearchHealthy();
+            }
+
+            LOG.info("indexBackEnd={}; isHealthy={}", idxBackEnd, isHealthy);
+        } catch (Exception exception) {
+            if (LOG.isDebugEnabled()) {
+                LOG.error("Error: isHealthy", exception);
+            }
+        }
+
+        if (!isHealthy && (prevIdxHealthCheckTime == 0 || currentTime - prevIdxHealthCheckTime > SOLR_STATUS_LOG_FREQUENCY_MS)) {
+            LOG.info("Backend Health: Unhealthy!");
+
+            prevIdxHealthCheckTime = currentTime;
+        }
+
+        return isHealthy;
+    }
+
     @Override
     public void applySearchWeight(String collectionName, Map<String, Integer> indexFieldName2SearchWeightMap) {
         SolrClient solrClient = null;
@@ -340,6 +381,19 @@ public class AtlasJanusGraphIndexClient implements AtlasGraphIndexClient {
         return Collections.EMPTY_LIST;
     }
 
+    private boolean isSolrHealthy() throws SolrServerException, IOException {
+        SolrClient client = Solr6Index.getSolrClient();
+
+        return client != null && client.ping(Constants.VERTEX_INDEX).getStatus() == SOLR_HEALTHY_STATUS;
+    }
+
+    private boolean isElasticsearchHealthy() throws IOException {
+        ElasticSearchClient client           = ElasticSearch7Index.getElasticSearchClient();
+        String              janusVertexIndex = ApplicationProperties.DEFAULT_INDEX_NAME + "_" + Constants.VERTEX_INDEX;
+
+        return client != null && client.indexExists(janusVertexIndex);
+    }
+
     private void graphManagementCommit(AtlasGraphManagement management) {
         try {
             management.commit();
