@@ -53,6 +53,7 @@ public class AtlasExportRequest implements Serializable {
     public static final String OPTION_ATTR_MATCH_TYPE = "matchType";
     public static final String OPTION_SKIP_LINEAGE = "skipLineage";
     public static final String OPTION_KEY_REPLICATED_TO = "replicatedTo";
+    public static final String OPTION_KEY_SKIP_UPDATE_REPLICATION_ATTR = "skipUpdateReplicationAttr";
     public static final String FETCH_TYPE_FULL = "full";
     public static final String FETCH_TYPE_CONNECTED = "connected";
     public static final String FETCH_TYPE_INCREMENTAL = "incremental";
@@ -62,6 +63,7 @@ public class AtlasExportRequest implements Serializable {
     public static final String MATCH_TYPE_CONTAINS = "contains";
     public static final String MATCH_TYPE_MATCHES = "matches";
     public static final String MATCH_TYPE_FOR_TYPE = "forType";
+    public static final String OMIT_ZIP_RESPONSE_FOR_EMPTY_EXPORT = "omitZipResponseForEmptyExport";
 
     private List<AtlasObjectId> itemsToExport = new ArrayList<>();
     private Map<String, Object> options = new HashMap<>();
@@ -140,6 +142,23 @@ public class AtlasExportRequest implements Serializable {
         return MapUtils.isNotEmpty(options) && options.containsKey(OPTION_KEY_REPLICATED_TO);
     }
 
+    @JsonIgnore
+    public boolean skipUpdateReplicationAttr() {
+        if (MapUtils.isNotEmpty(getOptions()) && getOptions().containsKey(OPTION_KEY_SKIP_UPDATE_REPLICATION_ATTR)) {
+
+            Object o = getOptions().get(AtlasExportRequest.OPTION_KEY_SKIP_UPDATE_REPLICATION_ATTR);
+            if (o instanceof String) {
+                return Boolean.parseBoolean((String) o);
+            }
+
+            if (o instanceof Boolean) {
+                return (Boolean) o;
+            }
+
+        }
+        return false;
+    }
+
     @JsonIgnore
     public String getOptionKeyReplicatedTo() {
         String replicateToServerName = isReplicationOptionSet() ? (String) options.get(OPTION_KEY_REPLICATED_TO) : StringUtils.EMPTY;
@@ -151,6 +170,25 @@ public class AtlasExportRequest implements Serializable {
         }
     }
 
+    public Boolean getOmitZipResponseForEmptyExport() {
+
+        if (MapUtils.isEmpty(getOptions()) ||
+                !getOptions().containsKey(AtlasExportRequest.OMIT_ZIP_RESPONSE_FOR_EMPTY_EXPORT)) {
+            return false;
+        }
+
+        Object o = getOptions().get(AtlasExportRequest.OMIT_ZIP_RESPONSE_FOR_EMPTY_EXPORT);
+        if (o instanceof String) {
+            return Boolean.parseBoolean((String) o);
+        }
+
+        if (o instanceof Boolean) {
+            return (Boolean) o;
+        }
+
+        return false;
+    }
+
     public StringBuilder toString(StringBuilder sb) {
         if (sb == null) {
             sb = new StringBuilder();
