@@ -37,6 +37,7 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
+import java.util.Set;
 
 import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
 import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;
@@ -60,6 +61,8 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
     private List<AtlasClassification>       classifications     = null;
     private List<String>                    meaningNames        = null;
     private List<AtlasTermAssignmentHeader> meanings            = null;
+    private Boolean                         isIncomplete        = Boolean.FALSE;
+    private Set<String>                     labels              = null;
 
     public AtlasEntityHeader() {
         this(null, null);
@@ -78,6 +81,7 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
 
         setClassificationNames(null);
         setClassifications(null);
+        setLabels(null);
     }
 
 
@@ -86,6 +90,7 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
         setGuid(guid);
         setClassificationNames(null);
         setClassifications(null);
+        setLabels(null);
     }
 
 
@@ -98,6 +103,8 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
             setDisplayText(other.getDisplayText());
             setClassificationNames(other.getClassificationNames());
             setClassifications(other.getClassifications());
+            setIsIncomplete(other.getIsIncomplete());
+            setLabels(other.getLabels());
         }
     }
 
@@ -106,6 +113,7 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
         setGuid(entity.getGuid());
         setStatus(entity.getStatus());
         setClassifications(entity.getClassifications());
+        setIsIncomplete(entity.getIsIncomplete());
 
         if (CollectionUtils.isNotEmpty(entity.getClassifications())) {
             this.classificationNames = new ArrayList<>(entity.getClassifications().size());
@@ -114,6 +122,10 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
                 this.classificationNames.add(classification.getTypeName());
             }
         }
+
+        if (CollectionUtils.isNotEmpty(entity.getLabels())) {
+            setLabels(entity.getLabels());
+        }
     }
 
     public String getGuid() {
@@ -156,6 +168,22 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
         this.classifications = classifications;
     }
 
+    public Set<String> getLabels() {
+        return labels;
+    }
+
+    public void setLabels(Set<String> labels) {
+        this.labels = labels;
+    }
+
+    public Boolean getIsIncomplete() {
+        return isIncomplete;
+    }
+
+    public void setIsIncomplete(Boolean isIncomplete) {
+        this.isIncomplete = isIncomplete;
+    }
+
     @Override
     public StringBuilder toString(StringBuilder sb) {
         if (sb == null) {
@@ -172,6 +200,10 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
         sb.append("classifications=[");
         AtlasBaseTypeDef.dumpObjects(classifications, sb);
         sb.append("], ");
+        sb.append("labels=[");
+        dumpObjects(labels, sb);
+        sb.append("], ");
+        sb.append("isIncomplete=").append(isIncomplete);
         super.toString(sb);
         sb.append('}');
 
@@ -190,12 +222,14 @@ public class AtlasEntityHeader extends AtlasStruct implements Serializable {
                        Objects.equals(classificationNames, that.classificationNames) &&
                        Objects.equals(meaningNames, that.classificationNames) &&
                        Objects.equals(classifications, that.classifications) &&
+                       Objects.equals(labels, that.labels) &&
+                       Objects.equals(isIncomplete, that.isIncomplete) &&
                        Objects.equals(meanings, that.meanings);
     }
 
     @Override
     public int hashCode() {
-        return Objects.hash(super.hashCode(), guid, status, displayText, classificationNames, classifications, meaningNames, meanings);
+        return Objects.hash(super.hashCode(), guid, status, displayText, classificationNames, classifications, meaningNames, meanings, isIncomplete, labels);
     }
 
     @Override
