@@ -17,14 +17,20 @@
  */
 package org.apache.atlas.kafka;
 
+import org.apache.atlas.AtlasException;
 import org.apache.atlas.notification.NotificationConsumer;
 import org.apache.atlas.notification.NotificationException;
 import org.apache.atlas.notification.NotificationInterface;
+import org.apache.commons.configuration.Configuration;
+import org.apache.commons.configuration.PropertiesConfiguration;
 import org.apache.kafka.clients.producer.Producer;
 import org.apache.kafka.clients.producer.ProducerRecord;
 import org.apache.kafka.clients.producer.RecordMetadata;
 import org.apache.kafka.common.TopicPartition;
+import org.mockito.Mockito;
 import org.testng.annotations.Test;
+
+import java.io.IOException;
 import java.util.Arrays;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -38,6 +44,7 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertEquals;
+import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
 import static org.testng.Assert.fail;
 
@@ -74,7 +81,7 @@ public class KafkaNotificationMockTest {
         KafkaNotification kafkaNotification = new KafkaNotification(configProperties);
 
         Producer producer = mock(Producer.class);
-        String topicName = kafkaNotification.getTopicName(NotificationInterface.NotificationType.HOOK);
+        String topicName = kafkaNotification.getProducerTopicName(NotificationInterface.NotificationType.HOOK);
         String message = "This is a test message";
         Future returnValue = mock(Future.class);
         TopicPartition topicPartition = new TopicPartition(topicName, 0);
@@ -96,7 +103,7 @@ public class KafkaNotificationMockTest {
         KafkaNotification kafkaNotification = new KafkaNotification(configProperties);
 
         Producer producer = mock(Producer.class);
-        String topicName = kafkaNotification.getTopicName(NotificationInterface.NotificationType.HOOK);
+        String topicName = kafkaNotification.getProducerTopicName(NotificationInterface.NotificationType.HOOK);
         String message = "This is a test message";
         Future returnValue = mock(Future.class);
         when(returnValue.get()).thenThrow(new RuntimeException("Simulating exception"));
@@ -121,7 +128,7 @@ public class KafkaNotificationMockTest {
         KafkaNotification kafkaNotification = new KafkaNotification(configProperties);
 
         Producer producer = mock(Producer.class);
-        String topicName = kafkaNotification.getTopicName(NotificationInterface.NotificationType.HOOK);
+        String topicName = kafkaNotification.getProducerTopicName(NotificationInterface.NotificationType.HOOK);
         String message1 = "This is a test message1";
         String message2 = "This is a test message2";
         Future returnValue1 = mock(Future.class);
