@@ -21,9 +21,11 @@ import com.google.common.annotations.VisibleForTesting;
 import org.apache.atlas.AtlasErrorCode;
 import org.apache.atlas.exception.AtlasBaseException;
 import org.apache.atlas.model.impexp.AtlasImportResult;
+import org.apache.atlas.model.typedef.AtlasBusinessMetadataDef;
 import org.apache.atlas.model.typedef.AtlasClassificationDef;
 import org.apache.atlas.model.typedef.AtlasEntityDef;
 import org.apache.atlas.model.typedef.AtlasEnumDef;
+import org.apache.atlas.model.typedef.AtlasRelationshipDef;
 import org.apache.atlas.model.typedef.AtlasStructDef;
 import org.apache.atlas.model.typedef.AtlasTypesDef;
 import org.apache.atlas.store.AtlasTypeDefStore;
@@ -48,15 +50,16 @@ public class TypeAttributeDifference {
     }
 
     public void updateTypes(AtlasTypesDef typeDefinitionMap, AtlasImportResult result) throws AtlasBaseException {
-
-        updateEntityDef(typeDefinitionMap, result);
-        updateClassificationDef(typeDefinitionMap, result);
-        updateEnumDef(typeDefinitionMap, result);
-        updateStructDef(typeDefinitionMap, result);
+        updateEnumDef(typeDefinitionMap.getEnumDefs(), result);
+        updateStructDef(typeDefinitionMap.getStructDefs(), result);
+        updateClassificationDef(typeDefinitionMap.getClassificationDefs(), result);
+        updateEntityDef(typeDefinitionMap.getEntityDefs(), result);
+        updateRelationshipDefs(typeDefinitionMap.getRelationshipDefs(), result);
+        updateBusinessMetadataDefs(typeDefinitionMap.getBusinessMetadataDefs(), result);
     }
 
-    private void updateEntityDef(AtlasTypesDef typeDefinitionMap, AtlasImportResult result) throws AtlasBaseException {
-        for (AtlasEntityDef def : typeDefinitionMap.getEntityDefs()) {
+    private void updateEntityDef(List<AtlasEntityDef> entityDefs, AtlasImportResult result) throws AtlasBaseException {
+        for (AtlasEntityDef def : entityDefs) {
             AtlasEntityDef existing = typeRegistry.getEntityDefByName(def.getName());
             if (existing != null && addAttributes(existing, def)) {
                 typeDefStore.updateEntityDefByName(existing.getName(), existing);
@@ -65,8 +68,8 @@ public class TypeAttributeDifference {
         }
     }
 
-    private void updateClassificationDef(AtlasTypesDef typeDefinitionMap, AtlasImportResult result) throws AtlasBaseException {
-        for (AtlasClassificationDef def : typeDefinitionMap.getClassificationDefs()) {
+    private void updateClassificationDef(List<AtlasClassificationDef> classificationDefs, AtlasImportResult result) throws AtlasBaseException {
+        for (AtlasClassificationDef def : classificationDefs) {
             AtlasClassificationDef existing = typeRegistry.getClassificationDefByName(def.getName());
             if (existing != null && addAttributes(existing, def)) {
                 typeDefStore.updateClassificationDefByName(existing.getName(), existing);
@@ -75,18 +78,20 @@ public class TypeAttributeDifference {
         }
     }
 
-    private void updateEnumDef(AtlasTypesDef typeDefinitionMap, AtlasImportResult result) throws AtlasBaseException {
-        for (AtlasEnumDef def : typeDefinitionMap.getEnumDefs()) {
+    private void updateEnumDef(List<AtlasEnumDef> enumDefs, AtlasImportResult result) throws AtlasBaseException {
+        for (AtlasEnumDef def : enumDefs) {
             AtlasEnumDef existing = typeRegistry.getEnumDefByName(def.getName());
             if (existing != null && addElements(existing, def)) {
                 typeDefStore.updateEnumDefByName(existing.getName(), existing);
                 result.incrementMeticsCounter("typedef:enum:update");
+            } else {
+
             }
         }
     }
 
-    private void updateStructDef(AtlasTypesDef typeDefinitionMap, AtlasImportResult result) throws AtlasBaseException {
-        for (AtlasStructDef def : typeDefinitionMap.getStructDefs()) {
+    private void updateStructDef(List<AtlasStructDef> structDefs, AtlasImportResult result) throws AtlasBaseException {
+        for (AtlasStructDef def : structDefs) {
             AtlasStructDef existing = typeRegistry.getStructDefByName(def.getName());
             if (existing != null && addAttributes(existing, def)) {
                 typeDefStore.updateStructDefByName(existing.getName(), existing);
@@ -95,6 +100,26 @@ public class TypeAttributeDifference {
         }
     }
 
+    private void updateRelationshipDefs(List<AtlasRelationshipDef> relationshipDefs, AtlasImportResult result) throws AtlasBaseException {
+        for (AtlasRelationshipDef def : relationshipDefs) {
+            AtlasRelationshipDef existing = typeRegistry.getRelationshipDefByName(def.getName());
+            if (existing != null && addAttributes(existing, def)) {
+                typeDefStore.updateRelationshipDefByName(existing.getName(), existing);
+                result.incrementMeticsCounter("typedef:relationshipdef:update");
+            }
+        }
+    }
+
+    private void updateBusinessMetadataDefs(List<AtlasBusinessMetadataDef> businessMetadataDefs, AtlasImportResult result) throws AtlasBaseException {
+        for (AtlasBusinessMetadataDef def : businessMetadataDefs) {
+            AtlasBusinessMetadataDef existing = typeRegistry.getBusinessMetadataDefByName(def.getName());
+            if (existing != null && addAttributes(existing, def)) {
+                typeDefStore.updateStructDefByName(existing.getName(), existing);
+                result.incrementMeticsCounter("typedef:businessmetadatadef:update");
+            }
+        }
+    }
+
     @VisibleForTesting
     boolean addElements(AtlasEnumDef existing, AtlasEnumDef incoming) throws AtlasBaseException {
         return addElements(existing, getElementsAbsentInExisting(existing, incoming));
