@@ -29,9 +29,12 @@ import org.apache.atlas.model.instance.AtlasObjectId;
 import org.apache.atlas.model.instance.EntityMutationResponse;
 import org.apache.atlas.repository.store.graph.v2.EntityStream;
 import org.apache.atlas.type.AtlasEntityType;
+import org.apache.atlas.bulkimport.BulkImportResponse;
 
+import java.io.InputStream;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 /**
  * Persistence/Retrieval API for AtlasEntity
@@ -71,6 +74,9 @@ public interface AtlasEntityStore {
      */
     AtlasEntityHeader getHeaderById(String guid) throws AtlasBaseException;
 
+
+    public AtlasEntityHeader getEntityHeaderByUniqueAttributes(AtlasEntityType entityType, Map<String, Object> uniqAttributes) throws AtlasBaseException;
+
     /**
      * Batch GET to retrieve entities by their ID
      * @param guid
@@ -145,6 +151,14 @@ public interface AtlasEntityStore {
      */
     EntityMutationResponse createOrUpdateForImport(EntityStream entityStream) throws AtlasBaseException;
 
+    /**
+     * Create or update  entities with parameters necessary for import process without commit. Caller will have to do take care of commit.
+     * @param entityStream AtlasEntityStream
+     * @return EntityMutationResponse Entity mutations operations with the corresponding set of entities on which these operations were performed
+     * @throws AtlasBaseException
+     */
+    EntityMutationResponse createOrUpdateForImportNoCommit(EntityStream entityStream) throws AtlasBaseException;
+
     /**
      * Update a single entity
      * @param objectId     ID of the entity
@@ -202,11 +216,17 @@ public interface AtlasEntityStore {
      */
 
     String getGuidByUniqueAttributes(AtlasEntityType entityType, Map<String, Object> uniqAttributes) throws AtlasBaseException;
+
     /*
      * Return list of deleted entity guids
      */
     EntityMutationResponse deleteByIds(List<String> guid) throws AtlasBaseException;
 
+    /*
+     * Return list of purged entity guids
+     */
+    EntityMutationResponse purgeByIds(Set<String> guids) throws AtlasBaseException;
+
     /**
      * Add classification(s)
      */
@@ -231,4 +251,46 @@ public interface AtlasEntityStore {
     AtlasClassification getClassification(String guid, String classificationName) throws AtlasBaseException;
 
     String setClassifications(AtlasEntityHeaders entityHeaders);
+
+    /**
+     * Set labels to given entity, if labels is null/empty, existing labels will all be removed.
+     */
+    void setLabels(String guid, Set<String> labels) throws AtlasBaseException;
+
+    /**
+     *
+     * @param guid
+     * @param businessAttrbutes
+     * @param isOverwrite
+     * @throws AtlasBaseException
+     */
+    void addOrUpdateBusinessAttributes(String guid, Map<String, Map<String, Object>> businessAttrbutes, boolean isOverwrite) throws AtlasBaseException;
+
+    /**
+     *
+     * @param guid
+     * @param businessAttributes
+     * @throws AtlasBaseException
+     */
+    void removeBusinessAttributes(String guid, Map<String, Map<String, Object>> businessAttributes) throws AtlasBaseException;
+
+    /**
+     * Remove given labels, if labels is null/empty, no labels will be removed. If any labels in
+     * labels set are non-existing labels, they will be ignored, only existing labels will be removed.
+     */
+    void removeLabels(String guid, Set<String> labels) throws AtlasBaseException;
+
+    /**
+     * Add given labels to the given entity, if labels is null/empty, no labels will be added.
+     */
+    void addLabels(String guid, Set<String> labels) throws AtlasBaseException;
+
+    /**
+     *
+     * @param inputStream
+     * @param fileName
+     * @throws AtlasBaseException
+     *
+     */
+    BulkImportResponse bulkCreateOrUpdateBusinessAttributes(InputStream inputStream, String fileName) throws AtlasBaseException;
 }
