@@ -74,6 +74,7 @@ public class RequestContext {
     private int         maxAttempts  = 1;
     private int         attemptCount = 1;
     private boolean     isImportInProgress = false;
+    private boolean     isMigrationInProgress = false;
     private boolean     isInNotificationProcessing = false;
     private boolean     isInTypePatching           = false;
     private boolean     createShellEntityForNonExistingReference = false;
@@ -202,6 +203,14 @@ public class RequestContext {
         return isImportInProgress;
     }
 
+    public boolean isMigrationInProgress() {
+        return isMigrationInProgress;
+    }
+
+    public void setMigrationInProgress(boolean migrationInProgress) {
+        isMigrationInProgress = migrationInProgress;
+    }
+
     public void setImportInProgress(boolean importInProgress) {
         isImportInProgress = importInProgress;
     }
