@@ -22,7 +22,9 @@ import com.google.common.util.concurrent.ThreadFactoryBuilder;
 import org.apache.atlas.*;
 import org.apache.atlas.exception.AtlasBaseException;
 import org.apache.atlas.ha.HAConfiguration;
+import org.apache.atlas.hook.AtlasHook;
 import org.apache.atlas.kafka.AtlasKafkaMessage;
+import org.apache.atlas.kafka.KafkaNotification;
 import org.apache.atlas.listener.ActiveStateChangeHandler;
 import org.apache.atlas.model.instance.AtlasEntity;
 import org.apache.atlas.model.instance.AtlasEntity.AtlasEntityWithExtInfo;
@@ -37,6 +39,7 @@ import org.apache.atlas.model.notification.HookNotification.EntityUpdateRequestV
 import org.apache.atlas.model.notification.HookNotification.EntityPartialUpdateRequestV2;
 import org.apache.atlas.notification.NotificationInterface.NotificationType;
 import org.apache.atlas.notification.preprocessor.EntityPreprocessor;
+import org.apache.atlas.notification.preprocessor.GenericEntityPreprocessor;
 import org.apache.atlas.notification.preprocessor.PreprocessorContext;
 import org.apache.atlas.notification.preprocessor.PreprocessorContext.PreprocessAction;
 import org.apache.atlas.repository.store.graph.EntityCorrelationStore;
@@ -81,8 +84,10 @@ import org.springframework.security.core.userdetails.UserDetails;
 import org.springframework.stereotype.Component;
 
 import javax.inject.Inject;
+import javax.ws.rs.core.Response;
 import java.time.Instant;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -91,6 +96,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.TreeMap;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
@@ -123,6 +129,9 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     private static final String EXCEPTION_CLASS_NAME_PERMANENTLOCKING_EXCEPTION = "PermanentLockingException";
     private static final int KAFKA_CONSUMER_SHUTDOWN_WAIT = 30000;
 
+    private static final String ATLAS_HOOK_CONSUMER_THREAD_NAME          = "atlas-hook-consumer-thread";
+    private static final String ATLAS_HOOK_UNSORTED_CONSUMER_THREAD_NAME = "atlas-hook-unsorted-consumer-thread";
+
     // from org.apache.hadoop.hive.ql.parse.SemanticAnalyzer
     public static final String DUMMY_DATABASE               = "_dummy_database";
     public static final String DUMMY_TABLE                  = "_dummy_table";
@@ -142,6 +151,8 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
 
     public static final String CONSUMER_SKIP_HIVE_COLUMN_LINEAGE_HIVE_20633                  = "atlas.notification.consumer.skip.hive_column_lineage.hive-20633";
     public static final String CONSUMER_SKIP_HIVE_COLUMN_LINEAGE_HIVE_20633_INPUTS_THRESHOLD = "atlas.notification.consumer.skip.hive_column_lineage.hive-20633.inputs.threshold";
+    public static final String CONSUMER_PREPROCESS_ENTITY_TYPE_IGNORE_PATTERN                = "atlas.notification.consumer.preprocess.entity.type.ignore.pattern";
+    public static final String CONSUMER_PREPROCESS_ENTITY_IGNORE_PATTERN                     = "atlas.notification.consumer.preprocess.entity.ignore.pattern";
     public static final String CONSUMER_PREPROCESS_HIVE_TABLE_IGNORE_PATTERN                 = "atlas.notification.consumer.preprocess.hive_table.ignore.pattern";
     public static final String CONSUMER_PREPROCESS_HIVE_TABLE_PRUNE_PATTERN                  = "atlas.notification.consumer.preprocess.hive_table.prune.pattern";
     public static final String CONSUMER_PREPROCESS_HIVE_TABLE_CACHE_SIZE                     = "atlas.notification.consumer.preprocess.hive_table.cache.size";
@@ -175,6 +186,8 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     private final boolean                       updateHiveProcessNameWithQualifiedName;
     private final int                           largeMessageProcessingTimeThresholdMs;
     private final boolean                       consumerDisabled;
+    private final List<Pattern>                 entityTypesToIgnore = new ArrayList<>();
+    private final List<Pattern>                 entitiesToIgnore = new ArrayList<>();
     private final List<Pattern>                 hiveTablesToIgnore = new ArrayList<>();
     private final List<Pattern>                 hiveTablesToPrune  = new ArrayList<>();
     private final List<String>                  hiveDummyDatabasesToIgnore;
@@ -195,6 +208,8 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     private       Instant                       nextStatsLogTime = AtlasMetricsCounter.getNextHourStartTime(Instant.now());
     private final Map<TopicPartition, Long>     lastCommittedPartitionOffset;
     private final EntityCorrelationManager      entityCorrelationManager;
+    private final long                          consumerMsgBufferingIntervalMS;
+    private final int                           consumerMsgBufferingBatchSize;
 
     @VisibleForTesting
     final int consumerRetryInterval;
@@ -230,14 +245,43 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
         largeMessageProcessingTimeThresholdMs         = applicationProperties.getInt("atlas.notification.consumer.large.message.processing.time.threshold.ms", 60 * 1000);  //  60 sec by default
         createShellEntityForNonExistingReference      = AtlasConfiguration.NOTIFICATION_CREATE_SHELL_ENTITY_FOR_NON_EXISTING_REF.getBoolean();
         authorizeUsingMessageUser                     = applicationProperties.getBoolean(CONSUMER_AUTHORIZE_USING_MESSAGE_USER, false);
+        consumerMsgBufferingIntervalMS                = AtlasConfiguration.NOTIFICATION_HOOK_CONSUMER_BUFFERING_INTERVAL.getInt() * 1000;
+        consumerMsgBufferingBatchSize                 = AtlasConfiguration.NOTIFICATION_HOOK_CONSUMER_BUFFERING_BATCH_SIZE.getInt();
 
         int authnCacheTtlSeconds = applicationProperties.getInt(CONSUMER_AUTHORIZE_AUTHN_CACHE_TTL_SECONDS, 300);
 
         authnCache = (authorizeUsingMessageUser && authnCacheTtlSeconds > 0) ? new PassiveExpiringMap<>(authnCacheTtlSeconds * 1000) : null;
 
+        String[] patternEntityTypesToIgnore = applicationProperties.getStringArray(CONSUMER_PREPROCESS_ENTITY_TYPE_IGNORE_PATTERN);
+        String[] patternEntitiesToIgnore = applicationProperties.getStringArray(CONSUMER_PREPROCESS_ENTITY_IGNORE_PATTERN);
+
         String[] patternHiveTablesToIgnore = applicationProperties.getStringArray(CONSUMER_PREPROCESS_HIVE_TABLE_IGNORE_PATTERN);
         String[] patternHiveTablesToPrune  = applicationProperties.getStringArray(CONSUMER_PREPROCESS_HIVE_TABLE_PRUNE_PATTERN);
 
+        if (patternEntityTypesToIgnore != null) {
+            for (String pattern: patternEntityTypesToIgnore) {
+                try {
+                    this.entityTypesToIgnore.add(Pattern.compile(pattern));
+                } catch (Throwable t) {
+                    LOG.warn("failed to compile pattern {}", pattern, t);
+                    LOG.warn("Ignoring invalid pattern in configuration {}: {}", CONSUMER_PREPROCESS_ENTITY_TYPE_IGNORE_PATTERN, pattern);
+                }
+            }
+            LOG.info("{}={}", CONSUMER_PREPROCESS_ENTITY_TYPE_IGNORE_PATTERN, entityTypesToIgnore);
+        }
+
+        if (patternEntitiesToIgnore != null) {
+            for (String pattern: patternEntitiesToIgnore) {
+                try {
+                    this.entitiesToIgnore.add(Pattern.compile(pattern));
+                } catch (Throwable t) {
+                    LOG.warn("failed to compile pattern {}", pattern, t);
+                    LOG.warn("Ignoring invalid pattern in configuration {}: {}", CONSUMER_PREPROCESS_ENTITY_IGNORE_PATTERN, pattern);
+                }
+            }
+            LOG.info("{}={}", CONSUMER_PREPROCESS_ENTITY_IGNORE_PATTERN, entitiesToIgnore);
+        }
+
         if (patternHiveTablesToIgnore != null) {
             for (String pattern : patternHiveTablesToIgnore) {
                 try {
@@ -350,17 +394,35 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     }
 
     private void startConsumers(ExecutorService executorService) {
-        int                                          numThreads            = applicationProperties.getInt(CONSUMER_THREADS_PROPERTY, 1);
+        int                                                           numThreads                  = applicationProperties.getInt(CONSUMER_THREADS_PROPERTY, 1);
+        Map<NotificationConsumer<HookNotification>, NotificationType> notificationConsumersByType = new HashMap<>();
+
         List<NotificationConsumer<HookNotification>> notificationConsumers = notificationInterface.createConsumers(NotificationType.HOOK, numThreads);
+        for (NotificationConsumer<HookNotification> notificationConsumer : notificationConsumers) {
+            notificationConsumersByType.put(notificationConsumer, NotificationType.HOOK);
+        }
+
+        if (AtlasHook.isHookMsgsSortEnabled) {
+            List<NotificationConsumer<HookNotification>> unsortedNotificationConsumers = notificationInterface.createConsumers(NotificationType.HOOK_UNSORTED, numThreads);
+            for (NotificationConsumer<HookNotification> unsortedNotificationConsumer : unsortedNotificationConsumers) {
+                notificationConsumersByType.put(unsortedNotificationConsumer, NotificationType.HOOK_UNSORTED);
+            }
+        }
 
         if (executorService == null) {
-            executorService = Executors.newFixedThreadPool(notificationConsumers.size(), new ThreadFactoryBuilder().setNameFormat(THREADNAME_PREFIX + " thread-%d").build());
+            executorService = Executors.newFixedThreadPool(notificationConsumersByType.size(), new ThreadFactoryBuilder().setNameFormat(THREADNAME_PREFIX + " thread-%d").build());
         }
 
         executors = executorService;
 
-        for (final NotificationConsumer<HookNotification> consumer : notificationConsumers) {
-            HookConsumer hookConsumer = new HookConsumer(consumer);
+        for (final NotificationConsumer<HookNotification> consumer : notificationConsumersByType.keySet()) {
+            String hookConsumerName   = ATLAS_HOOK_CONSUMER_THREAD_NAME;
+
+            if (notificationConsumersByType.get(consumer).equals(NotificationType.HOOK_UNSORTED)) {
+                hookConsumerName   = ATLAS_HOOK_UNSORTED_CONSUMER_THREAD_NAME;
+            }
+
+            HookConsumer hookConsumer = new HookConsumer(hookConsumerName, consumer);
 
             consumers.add(hookConsumer);
             executors.submit(hookConsumer);
@@ -529,8 +591,16 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
         private final List<String>                           failedMessages = new ArrayList<>();
         private final AdaptiveWaiter                         adaptiveWaiter = new AdaptiveWaiter(minWaitDuration, maxWaitDuration, minWaitDuration);
 
+        private int duplicateKeyCounter = 1;
+
         public HookConsumer(NotificationConsumer<HookNotification> consumer) {
-            super("atlas-hook-consumer-thread");
+            super(ATLAS_HOOK_CONSUMER_THREAD_NAME);
+
+            this.consumer = consumer;
+        }
+
+        public HookConsumer(String consumerThreadName, NotificationConsumer<HookNotification> consumer) {
+            super(consumerThreadName);
 
             this.consumer = consumer;
         }
@@ -548,10 +618,15 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
             try {
                 while (shouldRun.get()) {
                     try {
-                        List<AtlasKafkaMessage<HookNotification>> messages = consumer.receiveWithCheckedCommit(lastCommittedPartitionOffset);
-
-                        for (AtlasKafkaMessage<HookNotification> msg : messages) {
-                            handleMessage(msg);
+                        if (StringUtils.equals(ATLAS_HOOK_UNSORTED_CONSUMER_THREAD_NAME, this.getName())) {
+                            long                                            msgBufferingStartTime = System.currentTimeMillis();
+                            Map<String,AtlasKafkaMessage<HookNotification>> msgBuffer             = new TreeMap<>();
+                            sortAndPublishMsgsToAtlasHook(msgBufferingStartTime, msgBuffer);
+                        } else {
+                            List<AtlasKafkaMessage<HookNotification>> messages = consumer.receiveWithCheckedCommit(lastCommittedPartitionOffset);
+                            for (AtlasKafkaMessage<HookNotification> msg : messages) {
+                                handleMessage(msg);
+                            }
                         }
                     } catch (IllegalStateException ex) {
                         adaptiveWaiter.pause(ex);
@@ -576,6 +651,63 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
             }
         }
 
+        private void resetDuplicateKeyCounter() {
+            duplicateKeyCounter = 1;
+        }
+
+        private String getKey(String msgCreated, String source) {
+            return String.format("%s_%s", msgCreated, source);
+        }
+
+        private void sortMessages(AtlasKafkaMessage<HookNotification> msg, Map<String,AtlasKafkaMessage<HookNotification>> msgBuffer) {
+            String key = getKey(Long.toString(msg.getMsgCreated()), msg.getSource());
+            if (msgBuffer.containsKey(key)) { //Duplicate key can possible for messages from same source with same msgCreationTime
+                key = getKey(key, Integer.toString(duplicateKeyCounter));
+                duplicateKeyCounter++;
+            }
+            msgBuffer.put(key, msg);
+        }
+
+        void sortAndPublishMsgsToAtlasHook(long msgBufferingStartTime, Map<String,AtlasKafkaMessage<HookNotification>> msgBuffer) throws NotificationException {
+
+            List<AtlasKafkaMessage<HookNotification>> messages     = consumer.receiveRawRecordsWithCheckedCommit(lastCommittedPartitionOffset);
+            AtlasKafkaMessage<HookNotification>       maxOffsetMsg = null;
+            long                                      maxOffsetProcessed = 0;
+
+            messages.stream().forEach(x -> sortMessages(x, msgBuffer));
+
+            if (msgBuffer.size() < consumerMsgBufferingBatchSize && System.currentTimeMillis() - msgBufferingStartTime < consumerMsgBufferingIntervalMS) {
+                sortAndPublishMsgsToAtlasHook(msgBufferingStartTime, msgBuffer);
+                return;
+            }
+
+            for (AtlasKafkaMessage<HookNotification> msg : msgBuffer.values()) {
+                String hookTopic   = StringUtils.isNotEmpty(msg.getTopic()) ? msg.getTopic().split(KafkaNotification.UNSORTED_POSTFIX)[0] : KafkaNotification.ATLAS_HOOK_TOPIC;
+                if (maxOffsetProcessed == 0 || maxOffsetProcessed < msg.getOffset()) {
+                    maxOffsetMsg       = msg;
+                    maxOffsetProcessed = msg.getOffset();
+                }
+
+                ((KafkaNotification)notificationInterface).sendInternal(hookTopic,
+                        StringUtils.isNotEmpty(msg.getRawRecordData()) ? Arrays.asList(msg.getRawRecordData()) : Arrays.asList(msg.getMessage().toString()));
+            }
+
+
+            /** In case of failure while publishing sorted messages(above for loop), consuming of unsorted messages should start from the initial offset
+              * Explicitly keeping this for loop separate to commit messages only after sending all batch messages to hook topic
+              */
+            for (AtlasKafkaMessage<HookNotification> msg : msgBuffer.values()) {
+                commit(msg);
+            }
+
+            if (maxOffsetMsg != null) {
+                commit(maxOffsetMsg);
+            }
+
+            msgBuffer.clear();
+            resetDuplicateKeyCounter();
+        }
+
         @VisibleForTesting
         void handleMessage(AtlasKafkaMessage<HookNotification> kafkaMsg) {
             AtlasPerfTracer  perf           = null;
@@ -801,18 +933,34 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                         RequestContext.get().resetEntityGuidUpdates();
                         exceptionClassName = e.getClass().getSimpleName();
 
-                        if (numRetries == (maxRetries - 1)) {
-                            String strMessage = AbstractNotification.getMessageJson(message);
+                        // don't retry in following conditions:
+                        //  1. number of retry attempts reached configured count
+                        //  2. notification processing failed due to invalid data (non-existing type, entity, ..)
+                        boolean        maxRetriesReached    = numRetries == (maxRetries - 1);
+                        AtlasErrorCode errorCode            = (e instanceof AtlasBaseException) ? ((AtlasBaseException) e).getAtlasErrorCode() : null;
+                        boolean        unrecoverableFailure = errorCode != null && (Response.Status.NOT_FOUND.equals(errorCode.getHttpCode()) || Response.Status.BAD_REQUEST.equals(errorCode.getHttpCode()));
 
-                            LOG.warn("Max retries exceeded for message {}", strMessage, e);
+                        if (maxRetriesReached || unrecoverableFailure) {
+                            try {
+                                String strMessage = AbstractNotification.getMessageJson(message);
 
-                            stats.isFailedMsg = true;
+                                if (unrecoverableFailure) {
+                                    LOG.warn("Unrecoverable failure while processing message {}", strMessage, e);
+                                } else {
+                                    LOG.warn("Max retries exceeded for message {}", strMessage, e);
+                                }
 
-                            failedMessages.add(strMessage);
+                                stats.isFailedMsg = true;
 
-                            if (failedMessages.size() >= failedMsgCacheSize) {
-                                recordFailedMessages();
+                                failedMessages.add(strMessage);
+
+                                if (failedMessages.size() >= failedMsgCacheSize) {
+                                    recordFailedMessages();
+                                }
+                            } catch (Throwable t) {
+                                LOG.warn("error while recording failed message: type={}, topic={}, partition={}, offset={}", message.getType(), kafkaMsg.getTopic(), kafkaMsg.getPartition(), kafkaMsg.getOffset(), t);
                             }
+
                             return;
                         } else if (e instanceof org.apache.atlas.repository.graphdb.AtlasSchemaViolationException) {
                             LOG.warn("{}: Continuing: {}", exceptionClassName, e.getMessage());
@@ -847,10 +995,14 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                 metricsUtil.onNotificationProcessingComplete(kafkaMsg.getTopic(), kafkaMsg.getPartition(), kafkaMsg.getOffset(), stats);
 
                 if (stats.timeTakenMs > largeMessageProcessingTimeThresholdMs) {
-                    String strMessage = AbstractNotification.getMessageJson(message);
+                    try {
+                        String strMessage = AbstractNotification.getMessageJson(message);
 
-                    LOG.warn("msgProcessingTime={}, msgSize={}, topicOffset={}}", stats.timeTakenMs, strMessage.length(), kafkaMsg.getOffset());
-                    LARGE_MESSAGES_LOG.warn("{\"msgProcessingTime\":{},\"msgSize\":{},\"topicOffset\":{},\"data\":{}}", stats.timeTakenMs, strMessage.length(), kafkaMsg.getOffset(), strMessage);
+                        LOG.warn("msgProcessingTime={}, msgSize={}, topicOffset={}}", stats.timeTakenMs, strMessage.length(), kafkaMsg.getOffset());
+                        LARGE_MESSAGES_LOG.warn("{\"msgProcessingTime\":{},\"msgSize\":{},\"topicOffset\":{},\"data\":{}}", stats.timeTakenMs, strMessage.length(), kafkaMsg.getOffset(), strMessage);
+                    } catch (Throwable t) {
+                        LOG.warn("error while recording large message: msgProcessingTime={}, type={}, topic={}, partition={}, offset={}", stats.timeTakenMs, message.getType(), kafkaMsg.getTopic(), kafkaMsg.getPartition(), kafkaMsg.getOffset(), t);
+                    }
                 }
 
                 if (auditLog != null) {
@@ -974,6 +1126,36 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
         }
     }
 
+    private void preprocessEntities(PreprocessorContext context) {
+        GenericEntityPreprocessor genericEntityPreprocessor = new GenericEntityPreprocessor(this.entityTypesToIgnore, this.entitiesToIgnore);
+
+        List<AtlasEntity> entities = context.getEntities();
+
+        if (entities != null) {
+            for (int i = 0; i < entities.size(); i++) {
+                AtlasEntity entity = entities.get(i);
+                genericEntityPreprocessor.preprocess(entity, context);
+
+                if (context.isIgnoredEntity(entity.getGuid())) {
+                    entities.remove(i--);
+                }
+            }
+        }
+
+        Map<String, AtlasEntity> referredEntities = context.getReferredEntities();
+
+        if (referredEntities != null) {
+            for (Iterator<Map.Entry<String, AtlasEntity>> iterator = referredEntities.entrySet().iterator(); iterator.hasNext(); ) {
+                AtlasEntity entity = iterator.next().getValue();
+                genericEntityPreprocessor.preprocess(entity, context);
+
+                if (context.isIgnoredEntity(entity.getGuid())) {
+                    iterator.remove();
+                }
+            }
+        }
+    }
+
     private PreprocessorContext preProcessNotificationMessage(AtlasKafkaMessage<HookNotification> kafkaMsg) {
         PreprocessorContext context = null;
 
@@ -982,6 +1164,10 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                     hiveDummyDatabasesToIgnore, hiveDummyTablesToIgnore, hiveTablePrefixesToIgnore, hiveTypesRemoveOwnedRefAttrs,
                     rdbmsTypesRemoveOwnedRefAttrs, s3V2DirectoryPruneObjectPrefix, updateHiveProcessNameWithQualifiedName, entityCorrelationManager);
 
+            if (CollectionUtils.isNotEmpty(this.entityTypesToIgnore) || CollectionUtils.isNotEmpty(this.entitiesToIgnore)) {
+                preprocessEntities(context);
+            }
+
             if (context.isHivePreprocessEnabled()) {
                 preprocessHiveTypes(context);
             }
