@@ -23,6 +23,7 @@ import org.apache.atlas.ApplicationProperties;
 import org.apache.atlas.AtlasClient;
 import org.apache.atlas.AtlasConfiguration;
 import org.apache.atlas.AtlasErrorCode;
+import org.apache.atlas.AtlasException;
 import org.apache.atlas.authorize.AtlasAdminAccessRequest;
 import org.apache.atlas.authorize.AtlasAuthorizationUtils;
 import org.apache.atlas.authorize.AtlasEntityAccessRequest;
@@ -31,6 +32,7 @@ import org.apache.atlas.discovery.SearchContext;
 import org.apache.atlas.exception.AtlasBaseException;
 import org.apache.atlas.model.audit.AtlasAuditEntry;
 import org.apache.atlas.model.audit.AtlasAuditEntry.AuditOperation;
+import org.apache.atlas.model.audit.AuditReductionCriteria;
 import org.apache.atlas.model.audit.AuditSearchParameters;
 import org.apache.atlas.model.audit.EntityAuditEventV2;
 import org.apache.atlas.model.audit.EntityAuditEventV2.EntityAuditActionV2;
@@ -52,6 +54,7 @@ import org.apache.atlas.model.metrics.AtlasMetricsStat;
 import org.apache.atlas.model.patches.AtlasPatch.AtlasPatches;
 import org.apache.atlas.model.tasks.AtlasTask;
 import org.apache.atlas.repository.audit.AtlasAuditService;
+import org.apache.atlas.repository.audit.AtlasAuditReductionService;
 import org.apache.atlas.repository.audit.EntityAuditRepository;
 import org.apache.atlas.repository.impexp.AtlasServerService;
 import org.apache.atlas.repository.impexp.ExportImportAuditService;
@@ -65,6 +68,7 @@ import org.apache.atlas.services.MetricsService;
 import org.apache.atlas.tasks.TaskManagement;
 import org.apache.atlas.type.AtlasType;
 import org.apache.atlas.type.AtlasTypeRegistry;
+import org.apache.atlas.util.AtlasMetricsUtil;
 import org.apache.atlas.util.SearchTracker;
 import org.apache.atlas.utils.AtlasJson;
 import org.apache.atlas.utils.AtlasPerfTracer;
@@ -87,6 +91,7 @@ import org.springframework.security.core.Authentication;
 import org.springframework.security.core.GrantedAuthority;
 import org.springframework.security.core.context.SecurityContextHolder;
 import org.springframework.stereotype.Service;
+import org.apache.atlas.RequestContext;
 
 import javax.inject.Inject;
 import javax.inject.Singleton;
@@ -122,6 +127,7 @@ import java.util.concurrent.locks.ReentrantLock;
 import java.util.stream.Collectors;
 
 import static org.apache.atlas.web.filters.AtlasCSRFPreventionFilter.CSRF_TOKEN;
+import static javax.servlet.http.HttpServletResponse.SC_NO_CONTENT;
 
 
 /**
@@ -148,6 +154,7 @@ public class AdminResource {
     private static final String UI_DATE_TIMEZONE_FORMAT_ENABLED = "atlas.ui.date.timezone.format.enabled";
     private static final String UI_DATE_FORMAT                 = "atlas.ui.date.format";
     private static final String UI_DATE_DEFAULT_FORMAT         = "MM/DD/YYYY hh:mm:ss A";
+    private static final String UI_TASKS_TAB_USE_ENABLED       = "atlas.tasks.ui.tab.enabled";
     private static final String OPERATION_STATUS               = "operationStatus";
     private static final List TIMEZONE_LIST                    = Arrays.asList(TimeZone.getAvailableIDs());
 
@@ -186,6 +193,11 @@ public class AdminResource {
     private final  boolean                  isTasksEnabled;
     private final  boolean                  isOnDemandLineageEnabled;
     private final  int                      defaultLineageNodeCount;
+    private final  boolean                  isRelationshipSearchEnabled;
+    private final AtlasMetricsUtil atlasMetricsUtil;
+    private final  boolean                  isUiTasksTabEnabled;
+
+    private AtlasAuditReductionService auditReductionService;
 
     static {
         try {
@@ -202,7 +214,7 @@ public class AdminResource {
                          AtlasServerService serverService,
                          ExportImportAuditService exportImportAuditService, AtlasEntityStore entityStore,
                          AtlasPatchManager patchManager, AtlasAuditService auditService, EntityAuditRepository auditRepository,
-                         TaskManagement taskManagement, AtlasDebugMetricsSink debugMetricsRESTSink) {
+                         TaskManagement taskManagement, AtlasDebugMetricsSink debugMetricsRESTSink, AtlasAuditReductionService atlasAuditReductionService, AtlasMetricsUtil atlasMetricsUtil) {
         this.serviceState              = serviceState;
         this.metricsService            = metricsService;
         this.exportService             = exportService;
@@ -219,6 +231,8 @@ public class AdminResource {
         this.auditRepository           = auditRepository;
         this.taskManagement            = taskManagement;
         this.debugMetricsRESTSink      = debugMetricsRESTSink;
+        this.auditReductionService     = atlasAuditReductionService;
+        this.atlasMetricsUtil          = atlasMetricsUtil;
 
         if (atlasProperties != null) {
             this.defaultUIVersion = atlasProperties.getString(DEFAULT_UI_VERSION, UI_VERSION_V2);
@@ -226,16 +240,20 @@ public class AdminResource {
             this.uiDateFormat = atlasProperties.getString(UI_DATE_FORMAT, UI_DATE_DEFAULT_FORMAT);
             this.isDebugMetricsEnabled = AtlasConfiguration.DEBUG_METRICS_ENABLED.getBoolean();
             this.isTasksEnabled = AtlasConfiguration.TASKS_USE_ENABLED.getBoolean();
+            this.isUiTasksTabEnabled = AtlasConfiguration.UI_TASKS_TAB_USE_ENABLED.getBoolean();
             this.isOnDemandLineageEnabled = AtlasConfiguration.LINEAGE_ON_DEMAND_ENABLED.getBoolean();
             this.defaultLineageNodeCount = AtlasConfiguration.LINEAGE_ON_DEMAND_DEFAULT_NODE_COUNT.getInt();
+            this.isRelationshipSearchEnabled = AtlasConfiguration.RELATIONSHIP_SEARCH_ENABLED.getBoolean();
         } else {
             this.defaultUIVersion = UI_VERSION_V2;
             this.isTimezoneFormatEnabled = true;
             this.uiDateFormat = UI_DATE_DEFAULT_FORMAT;
             this.isDebugMetricsEnabled = false;
             this.isTasksEnabled = false;
+            this.isUiTasksTabEnabled = false;
             this.isOnDemandLineageEnabled = false;
             this.defaultLineageNodeCount = 3;
+            this.isRelationshipSearchEnabled = false;
         }
     }
 
@@ -385,8 +403,10 @@ public class AdminResource {
         responseData.put(UI_DATE_FORMAT, uiDateFormat);
         responseData.put(AtlasConfiguration.DEBUG_METRICS_ENABLED.getPropertyName(), isDebugMetricsEnabled);
         responseData.put(AtlasConfiguration.TASKS_USE_ENABLED.getPropertyName(), isTasksEnabled);
+        responseData.put(AtlasConfiguration.UI_TASKS_TAB_USE_ENABLED.getPropertyName(), isUiTasksTabEnabled);
         responseData.put(AtlasConfiguration.LINEAGE_ON_DEMAND_ENABLED.getPropertyName(), isOnDemandLineageEnabled);
         responseData.put(AtlasConfiguration.LINEAGE_ON_DEMAND_DEFAULT_NODE_COUNT.getPropertyName(), defaultLineageNodeCount);
+        responseData.put( AtlasConfiguration.RELATIONSHIP_SEARCH_ENABLED.getPropertyName(),isRelationshipSearchEnabled);
 
         if (AtlasConfiguration.SESSION_TIMEOUT_SECS.getInt() != -1) {
             responseData.put(AtlasConfiguration.SESSION_TIMEOUT_SECS.getPropertyName(), AtlasConfiguration.SESSION_TIMEOUT_SECS.getInt());
@@ -437,11 +457,17 @@ public class AdminResource {
             LOG.debug("==> AdminResource.scheduleSaveAndDeleteMetrics()");
         }
 
-        // auto persist
-        saveMetrics();
+        try {
+            // auto persist
+            saveMetrics();
+
+            // auto purge
+            metricsService.purgeMetricsStats();
+        } finally {
+            // After collecting metrics at regular intervals the request created is now cleared.
+            RequestContext.clear();
+        }
 
-        // auto purge
-        metricsService.purgeMetricsStats();
 
         if (LOG.isDebugEnabled()) {
             LOG.debug("<== AdminResource.scheduleSaveAndDeleteMetrics()");
@@ -604,7 +630,6 @@ public class AdminResource {
                                                          Servlets.getHostName(httpServletRequest),
                                                          AtlasAuthorizationUtils.getRequestIpAddress(httpServletRequest));
 
-            exportSink.close();
 
             httpServletResponse.addHeader("Content-Encoding","gzip");
             httpServletResponse.setContentType("application/zip");
@@ -612,9 +637,20 @@ public class AdminResource {
                                           "attachment; filename=" + result.getClass().getSimpleName());
             httpServletResponse.setHeader("Transfer-Encoding", "chunked");
 
-            httpServletResponse.getOutputStream().flush();
             isSuccessful = true;
-            return Response.ok().build();
+            if (CollectionUtils.isNotEmpty(exportSink.getGuids())) {
+                httpServletResponse.getOutputStream().flush();
+                return Response.ok().build();
+            } else {
+                if (request.getOmitZipResponseForEmptyExport()) {
+                    httpServletResponse.setStatus(SC_NO_CONTENT);
+                    httpServletResponse.getOutputStream().flush();
+                    return Response.status(Response.Status.NO_CONTENT).build();
+                } else {
+                    httpServletResponse.getOutputStream().flush();
+                    return Response.ok().build();
+                }
+            }
         } catch (IOException excp) {
             LOG.error("export() failed", excp);
 
@@ -820,6 +856,45 @@ public class AdminResource {
         }
     }
 
+    @POST
+    @Path("/audits/ageout")
+    @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Produces(Servlets.JSON_MEDIA_TYPE)
+    public List<AtlasTask> ageoutAuditData(AuditReductionCriteria auditReductionCriteria, @QueryParam("useAuditConfig") @DefaultValue("false") Boolean useAuditConfig) throws AtlasBaseException {
+        AtlasPerfTracer perf = null;
+        try {
+            AtlasAuthorizationUtils.verifyAccess(new AtlasAdminAccessRequest(AtlasPrivilege.ADMIN_AUDITS), "Admin Audits Ageout");
+
+            if (useAuditConfig) {
+                return auditReductionService.startAuditAgingByConfig();
+            }
+
+            if (!auditReductionCriteria.isAuditAgingEnabled()) {
+                LOG.warn("Audit aging should be enabled");
+                return null;
+            }
+
+            if (AtlasPerfTracer.isPerfTraceEnabled(PERF_LOG)) {
+                perf = AtlasPerfTracer.getPerfTracer(PERF_LOG, "AdminResource.ageoutAuditData(" + auditReductionCriteria + ")");
+            }
+
+            updateCriteriaWithDefaultValues(auditReductionCriteria);
+
+            List<Map<String, Object>> ageoutTypeCriteriaMap = auditReductionService.buildAgeoutCriteriaForAllAgingTypes(auditReductionCriteria);
+
+            return auditReductionService.startAuditAgingByCriteria(ageoutTypeCriteriaMap);
+
+        } finally {
+            AtlasPerfTracer.log(perf);
+        }
+    }
+
+    private void updateCriteriaWithDefaultValues(AuditReductionCriteria auditReductionCriteria) {
+        if (auditReductionCriteria.getDefaultAgeoutTTLInDays() <= 0) {
+            auditReductionCriteria.setDefaultAgeoutTTLInDays(AtlasConfiguration.ATLAS_AUDIT_DEFAULT_AGEOUT_TTL.getInt());
+        }
+    }
+
     @POST
     @Path("/audits")
     @Consumes(Servlets.JSON_MEDIA_TYPE)
@@ -1067,4 +1142,44 @@ public class AdminResource {
         }
     }
 
+    /**
+     * API to indicate service liveness
+     * @return response payload as json
+     * @throws AtlasBaseException
+     * @HTTP 200 if Atlas is alive
+     * @HTTP 500 if Atlas is not alive and requires a restart
+     */
+    @GET
+    @Path("/liveness")
+    public Response serviceLiveliness() throws AtlasBaseException {
+
+        if (serviceState.getState() == ServiceState.ServiceStateValue.ACTIVE || serviceState.getState() == ServiceState.ServiceStateValue.MIGRATING) {
+            return Response.status(Response.Status.OK).entity("Service is live").build();
+        } else {
+            LOG.error("Atlas Service is not live");
+            throw new AtlasBaseException(AtlasErrorCode.INTERNAL_ERROR, "Atlas Service is not live");
+        }
+    }
+
+    /**
+     * API to indicate service readiness
+     * @return response payload as json
+     * @throws AtlasBaseException
+     * @HTTP 200 if Atlas is alive and ready to accept client requests
+     * @HTTP 500 if Atlas is either not alive or not ready to accept client requests
+     */
+    @GET
+    @Path("/readiness")
+    public Response serviceReadiness() throws AtlasBaseException {
+
+        if((serviceState.getState() == ServiceState.ServiceStateValue.ACTIVE) &&
+                (atlasMetricsUtil.isIndexStoreActive() && atlasMetricsUtil.isBackendStoreActive())) {
+            return Response.status(Response.Status.OK).entity("Service is ready to accept requests").build();
+        }
+        else {
+            LOG.error("Service is not ready to accept client requests");
+            throw new AtlasBaseException(AtlasErrorCode.INTERNAL_ERROR, "Service not ready to accept client requests");
+        }
+    }
+
 }
